\name{ GSE13876 }
\alias{ GSE13876 }
\docType{data}
\title{ Survival-related profile, pathways, and transcription factors in ovarian cancer. }
\description{ Ovarian cancer has a poor prognosis due to advanced stage at presentation and either intrinsic or acquired resistance to classic cytotoxic drugs such as platinum and taxoids. Recent large clinical trials with different combinations and sequences of classic cytotoxic drugs indicate that further significant improvement in prognosis by this type of drugs is not to be expected. Currently a large number of drugs, targeting dysregulated molecular pathways in cancer cells have been developed and are introduced in the clinic. A major challenge is to identify those patients who will benefit from drugs targeting these specific dysregulated pathways.The aims of our study were (1) to develop a gene expression profile associated with overall survival in advanced stage serous ovarian cancer, (2) to assess the association of pathways and transcription factors with overall survival, and (3) to validate our identified profile and pathways/transcription factors in an independent set of ovarian cancers.According to a randomized design, profiling of 157 advanced stage serous ovarian cancers was performed in duplicate using approximately 35,000 70-mer oligonucleotide microarrays. A continuous predictor of overall survival was built taking into account well-known issues in microarray analysis, such as multiple testing and overfitting. A functional class scoring analysis was utilized to assess pathways/transcription factors for their association with overall survival. The prognostic value of genes that constitute our overall survival profile was validated on a fully independent, publicly available dataset of 118 well-defined primary serous ovarian cancers. Furthermore, functional class scoring analysis was also performed on this independent dataset to assess the similarities with results from our own dataset. An 86-gene overall survival profile discriminated between patients with unfavorable and favorable prognosis (median survival, 19 versus 41 mo, respectively; permutation p-value of log-rank statistic = 0.015) and maintained its independent prognostic value in multivariate analysis. Genes that composed the overall survival profile were also able to discriminate between the two risk groups in the independent dataset. In our dataset 17/167 pathways and 13/111 transcription factors were associated with overall survival, of which 16 and 12, respectively, were confirmed in the independent dataset.Our study provides new clues to genes, pathways, and transcription factors that contribute to the clinical outcome of serous ovarian cancer and might be exploited in designing new treatment strategies. }
\value{An expression set}
\format{
\preformatted{
experimentData(eset):
Experiment data
  Experimenter name: Crijns AP, Fehrmann RS, de Jong S, Gerbens F, Meersma GJ, Klip HG, Hollema H, Hofstra RM, te Meerman GJ, de Vries EG, van der Zee AG.Survival-related profile, pathways, and transcription factors in ovarian cancer. PLoS Med. 2009 Feb 3; 6(2):e24.
  Laboratory: Crijns, van der Zee 2009
  Contact information:
  Title: Survival-related profile, pathways, and transcription factors in ovarian cancer.
  URL:
  PMIDs: 19192944

  Abstract: A 371 word abstract is available. Use 'abstract' method.
  Information is available on: preprocessing
  notes:
   platform_title:
      Operon human v3 ~35K 70-mer two-color oligonucleotide microarrays
   platform_shorttitle:
      Operon v3 two-color
   platform_summary:
      OperonHumanV3
   platform_manufacturer:
      other
   platform_distribution:
      non-commercial
   platform_accession:
      GPL7759
   version:
      2015-09-22 19:11:43

featureData(eset):
An object of class 'AnnotatedDataFrame'
  featureNames: 1 2 ... 37629 (20939 total)
  varLabels: probeset gene EntrezGene.ID best_probe
  varMetadata: labelDescription

}}
\details{
\preformatted{
assayData: 20939 features, 157 samples
Platform type:
Overall survival time-to-event summary (in years):
Call: survfit(formula = Surv(time, cens) ~ -1)

      n  events  median 0.95LCL 0.95UCL
 157.00  113.00    2.05    1.56    2.71

---------------------------
Available sample meta-data:
---------------------------

alt_sample_name:
 151 NA's
   1  156

unique_patient_ID:
   Min. 1st Qu.  Median    Mean 3rd Qu.    Max.
      1      40      79      79     118     157

sample_type:
tumor
  157

histological_type:
ser
157

primarysite:
 ov
157

summarygrade:
high  low NA's
  85   59   13

summarystage:
late
 157

grade:
   1    2    3    4 NA's
  14   45   82    3   13

age_at_initial_pathologic_diagnosis:
   Min. 1st Qu.  Median    Mean 3rd Qu.    Max.
  21.00   50.00   60.00   57.95   67.00   84.00

days_to_death:
   Min. 1st Qu.  Median    Mean 3rd Qu.    Max.
     30     360     630    1100    1470    7020

vital_status:
deceased   living
     113       44

uncurated_author_metadata:
                                                                                                                                  title: Ovarian tumor sample 100 / Ovarian tumor sample 101///geo_accession: GSM405638 / GSM405874///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 41///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 25///characteristics_ch1.3: age: 54///characteristics_ch1.4: sample nr: 197///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405638/GSM405638.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405874/GSM405874.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                   title: Ovarian tumor sample 103 / Ovarian tumor sample 104///geo_accession: GSM405608 / GSM405784///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 42///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 2///characteristics_ch1.3: age: 57///characteristics_ch1.4: sample nr: 170///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405608/GSM405608.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405784/GSM405784.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
       title: Ovarian tumor sample 105 / Ovarian tumor sample 106///geo_accession: GSM405628 / GSM405629///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 43///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 59///characteristics_ch1.3: age: 63///characteristics_ch1.4: sample nr: 402///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics: STATUS: 0 = end of follow-up or death unrelated to ovarian cancer ;  1 = death due to ovarian cancer FUMND: Months from primary surgery SAMPLE NR: Unique RNA reference number///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405628/GSM405628.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405629/GSM405629.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                    title: Ovarian tumor sample 108 / Ovarian tumor sample 109///geo_accession: GSM405700 / GSM405943///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 44///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 16///characteristics_ch1.3: age: 66///characteristics_ch1.4: sample nr: 5///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405700/GSM405700.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405943/GSM405943.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
          title: Ovarian tumor sample 10 / Ovarian tumor sample 11///geo_accession: GSM405902 / GSM405903///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 24///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 5///characteristics_ch1.3: age: 52///characteristics_ch1.4: sample nr: 459///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics: STATUS: 0 = end of follow-up or death unrelated to ovarian cancer ;  1 = death due to ovarian cancer FUMND: Months from primary surgery SAMPLE NR: Unique RNA reference number///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405902/GSM405902.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405903/GSM405903.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
       title: Ovarian tumor sample 111 / Ovarian tumor sample 112///geo_accession: GSM405598 / GSM405599///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 45///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 64///characteristics_ch1.3: age: 66///characteristics_ch1.4: sample nr: 343///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics: STATUS: 0 = end of follow-up or death unrelated to ovarian cancer ;  1 = death due to ovarian cancer FUMND: Months from primary surgery SAMPLE NR: Unique RNA reference number///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405598/GSM405598.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405599/GSM405599.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
       title: Ovarian tumor sample 115 / Ovarian tumor sample 117///geo_accession: GSM405774 / GSM405776///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 46///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 11///characteristics_ch1.3: age: 56///characteristics_ch1.4: sample nr: 345///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics: STATUS: 0 = end of follow-up or death unrelated to ovarian cancer ;  1 = death due to ovarian cancer FUMND: Months from primary surgery SAMPLE NR: Unique RNA reference number///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405774/GSM405774.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405776/GSM405776.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 119 / Ovarian tumor sample 120///geo_accession: GSM405600 / GSM405805///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 47///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 33///characteristics_ch1.3: age: 43///characteristics_ch1.4: sample nr: 379///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405600/GSM405600.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405805/GSM405805.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 122 / Ovarian tumor sample 123///geo_accession: GSM405651 / GSM405794///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 48///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 73///characteristics_ch1.3: age: 73///characteristics_ch1.4: sample nr: 211///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405651/GSM405651.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405794/GSM405794.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 124 / Ovarian tumor sample 125///geo_accession: GSM405659 / GSM405787///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 49///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 30///characteristics_ch1.3: age: 54///characteristics_ch1.4: sample nr: 346///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405659/GSM405659.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405787/GSM405787.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
       title: Ovarian tumor sample 126 / Ovarian tumor sample 127///geo_accession: GSM405614 / GSM405615///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 50///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 18///characteristics_ch1.3: age: 48///characteristics_ch1.4: sample nr: 235///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics: STATUS: 0 = end of follow-up or death unrelated to ovarian cancer ;  1 = death due to ovarian cancer FUMND: Months from primary surgery SAMPLE NR: Unique RNA reference number///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405614/GSM405614.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405615/GSM405615.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                   title: Ovarian tumor sample 129 / Ovarian tumor sample 130///geo_accession: GSM405641 / GSM405887///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 1///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 41///characteristics_ch1.3: age: 55///characteristics_ch1.4: sample nr: 200///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405641/GSM405641.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405887/GSM405887.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                   title: Ovarian tumor sample 131 / Ovarian tumor sample 132///geo_accession: GSM405597 / GSM405684///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 51///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 8///characteristics_ch1.3: age: 57///characteristics_ch1.4: sample nr: 160///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405597/GSM405597.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405684/GSM405684.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                 title: Ovarian tumor sample 133 / Ovarian tumor sample 134///geo_accession: GSM405756 / GSM405914///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 52///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 234///characteristics_ch1.3: age: 26///characteristics_ch1.4: sample nr: 468///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405756/GSM405756.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405914/GSM405914.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 135 / Ovarian tumor sample 136///geo_accession: GSM405658 / GSM405753///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 53///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 66///characteristics_ch1.3: age: 60///characteristics_ch1.4: sample nr: 219///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405658/GSM405658.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405753/GSM405753.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 137 / Ovarian tumor sample 138///geo_accession: GSM405568 / GSM405946///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 100///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 18///characteristics_ch1.3: age: 62///characteristics_ch1.4: sample nr: 61///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405568/GSM405568.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405946/GSM405946.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                 title: Ovarian tumor sample 139 / Ovarian tumor sample 140///geo_accession: GSM405890 / GSM405937///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 101///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 42///characteristics_ch1.3: age: 57///characteristics_ch1.4: sample nr: 450///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405890/GSM405890.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405937/GSM405937.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
         title: Ovarian tumor sample 13 / Ovarian tumor sample 14///geo_accession: GSM405578 / GSM405580///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 85///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 25///characteristics_ch1.3: age: 51///characteristics_ch1.4: sample nr: 248///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics: STATUS: 0 = end of follow-up or death unrelated to ovarian cancer ;  1 = death due to ovarian cancer FUMND: Months from primary surgery SAMPLE NR: Unique RNA reference number///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405578/GSM405578.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405580/GSM405580.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                title: Ovarian tumor sample 141 / Ovarian tumor sample 142///geo_accession: GSM405569 / GSM405601///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 102///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 132///characteristics_ch1.3: age: 65///characteristics_ch1.4: sample nr: 117///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405569/GSM405569.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405601/GSM405601.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                   title: Ovarian tumor sample 145 / Ovarian tumor sample 146///geo_accession: GSM405817 / GSM405819///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 54///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 2///characteristics_ch1.3: age: 71///characteristics_ch1.4: sample nr: 385///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405817/GSM405817.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405819/GSM405819.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 147 / Ovarian tumor sample 148///geo_accession: GSM405631 / GSM405904///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 55///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 12///characteristics_ch1.3: age: 65///characteristics_ch1.4: sample nr: 190///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405631/GSM405631.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405904/GSM405904.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                 title: Ovarian tumor sample 149 / Ovarian tumor sample 150///geo_accession: GSM405716 / GSM405789///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 56///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 133///characteristics_ch1.3: age: 49///characteristics_ch1.4: sample nr: 349///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405716/GSM405716.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405789/GSM405789.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                              title: Ovarian tumor sample 151///geo_accession: GSM405740///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 103///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 20///characteristics_ch1.3: age: 57///characteristics_ch1.4: sample nr: 305///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics: STATUS: 0 = end of follow-up or death unrelated to ovarian cancer ;  1 = death due to ovarian cancer FUMND: Months from primary surgery SAMPLE NR: Unique RNA reference number///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405740/GSM405740.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 152 / Ovarian tumor sample 153///geo_accession: GSM405679 / GSM405822///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 57///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 20///characteristics_ch1.3: age: 71///characteristics_ch1.4: sample nr: 392///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405679/GSM405679.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405822/GSM405822.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 155 / Ovarian tumor sample 156///geo_accession: GSM405769 / GSM405898///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 58///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 59///characteristics_ch1.3: age: 46///characteristics_ch1.4: sample nr: 455///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405769/GSM405769.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405898/GSM405898.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                   title: Ovarian tumor sample 157 / Ovarian tumor sample 158///geo_accession: GSM405701 / GSM405871///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 59///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 2///characteristics_ch1.3: age: 45///characteristics_ch1.4: sample nr: 263///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405701/GSM405701.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405871/GSM405871.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                 title: Ovarian tumor sample 159 / Ovarian tumor sample 160///geo_accession: GSM405722 / GSM405809///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 104///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 49///characteristics_ch1.3: age: 37///characteristics_ch1.4: sample nr: 283///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405722/GSM405722.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405809/GSM405809.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 161 / Ovarian tumor sample 162///geo_accession: GSM405826 / GSM405930///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 60///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 28///characteristics_ch1.3: age: 66///characteristics_ch1.4: sample nr: 393///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405826/GSM405826.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405930/GSM405930.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                 title: Ovarian tumor sample 163 / Ovarian tumor sample 164///geo_accession: GSM405865 / GSM405916///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 105///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 59///characteristics_ch1.3: age: 65///characteristics_ch1.4: sample nr: 471///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405865/GSM405865.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405916/GSM405916.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
       title: Ovarian tumor sample 165 / Ovarian tumor sample 166///geo_accession: GSM405634 / GSM405635///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 61///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 67///characteristics_ch1.3: age: 72///characteristics_ch1.4: sample nr: 193///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics: STATUS: 0 = end of follow-up or death unrelated to ovarian cancer ;  1 = death due to ovarian cancer FUMND: Months from primary surgery SAMPLE NR: Unique RNA reference number///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405634/GSM405634.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405635/GSM405635.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                   title: Ovarian tumor sample 169 / Ovarian tumor sample 170///geo_accession: GSM405556 / GSM405695///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 62///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 7///characteristics_ch1.3: age: 61///characteristics_ch1.4: sample nr: 258///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405556/GSM405556.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405695/GSM405695.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                 title: Ovarian tumor sample 171 / Ovarian tumor sample 172///geo_accession: GSM405559 / GSM405866///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 106///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 12///characteristics_ch1.3: age: 49///characteristics_ch1.4: sample nr: 429///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405559/GSM405559.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405866/GSM405866.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 173 / Ovarian tumor sample 174///geo_accession: GSM405652 / GSM405959///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 63///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 16///characteristics_ch1.3: age: 51///characteristics_ch1.4: sample nr: 213///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405652/GSM405652.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405959/GSM405959.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 176 / Ovarian tumor sample 177///geo_accession: GSM405746 / GSM405864///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 64///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 53///characteristics_ch1.3: age: 63///characteristics_ch1.4: sample nr: 427///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405746/GSM405746.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405864/GSM405864.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                title: Ovarian tumor sample 178 / Ovarian tumor sample 179///geo_accession: GSM405882 / GSM405913///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 107///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 119///characteristics_ch1.3: age: 21///characteristics_ch1.4: sample nr: 440///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405882/GSM405882.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405913/GSM405913.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 180 / Ovarian tumor sample 181///geo_accession: GSM405591 / GSM405654///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 65///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 70///characteristics_ch1.3: age: 61///characteristics_ch1.4: sample nr: 214///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405591/GSM405591.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405654/GSM405654.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 185 / Ovarian tumor sample 186///geo_accession: GSM405613 / GSM405741///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 66///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 10///characteristics_ch1.3: age: 75///characteristics_ch1.4: sample nr: 179///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405613/GSM405613.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405741/GSM405741.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                   title: Ovarian tumor sample 187 / Ovarian tumor sample 188///geo_accession: GSM405791 / GSM405878///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 67///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 4///characteristics_ch1.3: age: 22///characteristics_ch1.4: sample nr: 352///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405791/GSM405791.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405878/GSM405878.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 189 / Ovarian tumor sample 190///geo_accession: GSM405626 / GSM405868///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 68///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 30///characteristics_ch1.3: age: 72///characteristics_ch1.4: sample nr: 431///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405626/GSM405626.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405868/GSM405868.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                     title: Ovarian tumor sample 18 / Ovarian tumor sample 19///geo_accession: GSM405612 / GSM405642///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 86///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 9///characteristics_ch1.3: age: 68///characteristics_ch1.4: sample nr: 177///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405612/GSM405612.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405642/GSM405642.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                   title: Ovarian tumor sample 191 / Ovarian tumor sample 192///geo_accession: GSM405566 / GSM405610///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 69///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 8///characteristics_ch1.3: age: 54///characteristics_ch1.4: sample nr: 176///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405566/GSM405566.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405610/GSM405610.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
       title: Ovarian tumor sample 193 / Ovarian tumor sample 194///geo_accession: GSM405821 / GSM405823///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 70///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 17///characteristics_ch1.3: age: 62///characteristics_ch1.4: sample nr: 395///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics: STATUS: 0 = end of follow-up or death unrelated to ovarian cancer ;  1 = death due to ovarian cancer FUMND: Months from primary surgery SAMPLE NR: Unique RNA reference number///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405821/GSM405821.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405823/GSM405823.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                    title: Ovarian tumor sample 196 / Ovarian tumor sample 197///geo_accession: GSM405603 / GSM405900///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 2///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 1///characteristics_ch1.3: age: 64///characteristics_ch1.4: sample nr: 457///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405603/GSM405603.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405900/GSM405900.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                   title: Ovarian tumor sample 198 / Ovarian tumor sample 199///geo_accession: GSM405562 / GSM405852///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 3///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 47///characteristics_ch1.3: age: 55///characteristics_ch1.4: sample nr: 413///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405562/GSM405562.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405852/GSM405852.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                      title: Ovarian tumor sample 1 / Ovarian tumor sample 2///geo_accession: GSM405750 / GSM405810///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 21///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 36///characteristics_ch1.3: age: 66///characteristics_ch1.4: sample nr: 383///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405750/GSM405750.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405810/GSM405810.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 200 / Ovarian tumor sample 201///geo_accession: GSM405583 / GSM405593///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 71///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 13///characteristics_ch1.3: age: 43///characteristics_ch1.4: sample nr: 133///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405583/GSM405583.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405593/GSM405593.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                   title: Ovarian tumor sample 202 / Ovarian tumor sample 203///geo_accession: GSM405637 / GSM405655///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 4///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 22///characteristics_ch1.3: age: 72///characteristics_ch1.4: sample nr: 217///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405637/GSM405637.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405655/GSM405655.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                    title: Ovarian tumor sample 206 / Ovarian tumor sample 207///geo_accession: GSM405857 / GSM405901///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 5///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 7///characteristics_ch1.3: age: 40///characteristics_ch1.4: sample nr: 458///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405857/GSM405857.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405901/GSM405901.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 208 / Ovarian tumor sample 209///geo_accession: GSM405584 / GSM405661///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 72///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 18///characteristics_ch1.3: age: 53///characteristics_ch1.4: sample nr: 223///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405584/GSM405584.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405661/GSM405661.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                   title: Ovarian tumor sample 210 / Ovarian tumor sample 211///geo_accession: GSM405757 / GSM405800///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 6///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 64///characteristics_ch1.3: age: 70///characteristics_ch1.4: sample nr: 376///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405757/GSM405757.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405800/GSM405800.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                   title: Ovarian tumor sample 212 / Ovarian tumor sample 213///geo_accession: GSM405699 / GSM405935///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 7///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 17///characteristics_ch1.3: age: 72///characteristics_ch1.4: sample nr: 262///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405699/GSM405699.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405935/GSM405935.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                   title: Ovarian tumor sample 214 / Ovarian tumor sample 215///geo_accession: GSM405713 / GSM405872///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 73///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 5///characteristics_ch1.3: age: 65///characteristics_ch1.4: sample nr: 435///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405713/GSM405713.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405872/GSM405872.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                            title: Ovarian tumor sample 216 / Ovarian tumor sample 217///geo_accession: GSM405669 / GSM405754///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 8///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 12///characteristics_ch1.3: age: 71///characteristics_ch1.4: sample nr / sample nr///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405669/GSM405669.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405754/GSM405754.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                    title: Ovarian tumor sample 21 / Ovarian tumor sample 22///geo_accession: GSM405625 / GSM405644///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 25///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 31///characteristics_ch1.3: age: 68///characteristics_ch1.4: sample nr: 186///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405625/GSM405625.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405644/GSM405644.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                 title: Ovarian tumor sample 222 / Ovarian tumor sample 223///geo_accession: GSM405680 / GSM405856///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 108///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 22///characteristics_ch1.3: age: 61///characteristics_ch1.4: sample nr: 419///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405680/GSM405680.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405856/GSM405856.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                 title: Ovarian tumor sample 224 / Ovarian tumor sample 225///geo_accession: GSM405742 / GSM405747///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 109///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 12///characteristics_ch1.3: age: 53///characteristics_ch1.4: sample nr: 307///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405742/GSM405742.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405747/GSM405747.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 228 / Ovarian tumor sample 229///geo_accession: GSM405665 / GSM405832///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 74///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 12///characteristics_ch1.3: age: 64///characteristics_ch1.4: sample nr: 396///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405665/GSM405665.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405832/GSM405832.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
        title: Ovarian tumor sample 230 / Ovarian tumor sample 231///geo_accession: GSM405570 / GSM405571///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 9///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 18///characteristics_ch1.3: age: 42///characteristics_ch1.4: sample nr: 336///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics: STATUS: 0 = end of follow-up or death unrelated to ovarian cancer ;  1 = death due to ovarian cancer FUMND: Months from primary surgery SAMPLE NR: Unique RNA reference number///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405570/GSM405570.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405571/GSM405571.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 235 / Ovarian tumor sample 236///geo_accession: GSM405630 / GSM405668///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 10///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 80///characteristics_ch1.3: age: 54///characteristics_ch1.4: sample nr: 232///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405630/GSM405630.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405668/GSM405668.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
       title: Ovarian tumor sample 237 / Ovarian tumor sample 238///geo_accession: GSM405807 / GSM405808///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 75///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 13///characteristics_ch1.3: age: 58///characteristics_ch1.4: sample nr: 438///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics: STATUS: 0 = end of follow-up or death unrelated to ovarian cancer ;  1 = death due to ovarian cancer FUMND: Months from primary surgery SAMPLE NR: Unique RNA reference number///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405807/GSM405807.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405808/GSM405808.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                   title: Ovarian tumor sample 241 / Ovarian tumor sample 242///geo_accession: GSM405609 / GSM405928///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 11///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 5///characteristics_ch1.3: age: 48///characteristics_ch1.4: sample nr: 173///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405609/GSM405609.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405928/GSM405928.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 244 / Ovarian tumor sample 245///geo_accession: GSM405624 / GSM405732///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 12///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 21///characteristics_ch1.3: age: 67///characteristics_ch1.4: sample nr: 185///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405624/GSM405624.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405732/GSM405732.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                   title: Ovarian tumor sample 246 / Ovarian tumor sample 247///geo_accession: GSM405686 / GSM405708///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 76///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 2///characteristics_ch1.3: age: 78///characteristics_ch1.4: sample nr: 272///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405686/GSM405686.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405708/GSM405708.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                 title: Ovarian tumor sample 248 / Ovarian tumor sample 249///geo_accession: GSM405724 / GSM405853///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 110///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 41///characteristics_ch1.3: age: 73///characteristics_ch1.4: sample nr: 285///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405724/GSM405724.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405853/GSM405853.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                     title: Ovarian tumor sample 24 / Ovarian tumor sample 25///geo_accession: GSM405707 / GSM405954///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 87///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 19///characteristics_ch1.3: age: 66///characteristics_ch1.4: sample nr: 67///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405707/GSM405707.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405954/GSM405954.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Ovarian tumor sample 250 / Ovarian tumor sample 251///geo_accession: GSM405899 / GSM405926///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 77///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 11///characteristics_ch1.3: age: 25///characteristics_ch1.4: sample nr / sample nr///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics: STATUS: 0 = end of follow-up or death unrelated to ovarian cancer ;  1 = death due to ovarian cancer FUMND: Months from primary surgery SAMPLE NR: Unique RNA reference number///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405899/GSM405899.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405926/GSM405926.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 254 / Ovarian tumor sample 255///geo_accession: GSM405586 / GSM405633///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 78///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 14///characteristics_ch1.3: age: 59///characteristics_ch1.4: sample nr: 191///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405586/GSM405586.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405633/GSM405633.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                 title: Ovarian tumor sample 256 / Ovarian tumor sample 257///geo_accession: GSM405561 / GSM405621///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 111///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 59///characteristics_ch1.3: age: 61///characteristics_ch1.4: sample nr: 111///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405561/GSM405561.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405621/GSM405621.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
       title: Ovarian tumor sample 258 / Ovarian tumor sample 259///geo_accession: GSM405696 / GSM405697///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 13///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 19///characteristics_ch1.3: age: 41///characteristics_ch1.4: sample nr: 259///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics: STATUS: 0 = end of follow-up or death unrelated to ovarian cancer ;  1 = death due to ovarian cancer FUMND: Months from primary surgery SAMPLE NR: Unique RNA reference number///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405696/GSM405696.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405697/GSM405697.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                   title: Ovarian tumor sample 261 / Ovarian tumor sample 262///geo_accession: GSM405678 / GSM405863///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 14///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 9///characteristics_ch1.3: age: 60///characteristics_ch1.4: sample nr: 239///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405678/GSM405678.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405863/GSM405863.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                   title: Ovarian tumor sample 263 / Ovarian tumor sample 264///geo_accession: GSM405730 / GSM405798///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 15///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 6///characteristics_ch1.3: age: 68///characteristics_ch1.4: sample nr: 371///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405730/GSM405730.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405798/GSM405798.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                 title: Ovarian tumor sample 265 / Ovarian tumor sample 266///geo_accession: GSM405606 / GSM405951///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 112///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 92///characteristics_ch1.3: age: 51///characteristics_ch1.4: sample nr: 168///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405606/GSM405606.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405951/GSM405951.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                 title: Ovarian tumor sample 267 / Ovarian tumor sample 268///geo_accession: GSM405592 / GSM405703///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 113///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 31///characteristics_ch1.3: age: 62///characteristics_ch1.4: sample nr: 266///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405592/GSM405592.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405703/GSM405703.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                          title: Ovarian tumor sample 269 / Ovarian tumor sample 270///geo_accession: GSM405619 / GSM405650///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 114///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 24///characteristics_ch1.3: age: 74///characteristics_ch1.4: sample nr / sample nr///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405619/GSM405619.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405650/GSM405650.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                    title: Ovarian tumor sample 26 / Ovarian tumor sample 27///geo_accession: GSM405675 / GSM405758///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 26///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 61///characteristics_ch1.3: age: 71///characteristics_ch1.4: sample nr: 329///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405675/GSM405675.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405758/GSM405758.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
      title: Ovarian tumor sample 273 / Ovarian tumor sample 274///geo_accession: GSM405579 / GSM405581///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 115///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 14///characteristics_ch1.3: age: 60///characteristics_ch1.4: sample nr: 131///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics: STATUS: 0 = end of follow-up or death unrelated to ovarian cancer ;  1 = death due to ovarian cancer FUMND: Months from primary surgery SAMPLE NR: Unique RNA reference number///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405579/GSM405579.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405581/GSM405581.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 278 / Ovarian tumor sample 279///geo_accession: GSM405683 / GSM405879///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 79///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 16///characteristics_ch1.3: age: 39///characteristics_ch1.4: sample nr: 439///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405683/GSM405683.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405879/GSM405879.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                title: Ovarian tumor sample 280 / Ovarian tumor sample 281///geo_accession: GSM405859 / GSM405917///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 116///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 117///characteristics_ch1.3: age: 52///characteristics_ch1.4: sample nr: 472///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405859/GSM405859.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405917/GSM405917.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                title: Ovarian tumor sample 282 / Ovarian tumor sample 283///geo_accession: GSM405611 / GSM405704///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 117///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 213///characteristics_ch1.3: age: 43///characteristics_ch1.4: sample nr: 267///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405611/GSM405611.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405704/GSM405704.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
      title: Ovarian tumor sample 284 / Ovarian tumor sample 285///geo_accession: GSM405645 / GSM405647///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 118///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 43///characteristics_ch1.3: age: 42///characteristics_ch1.4: sample nr: 202///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics: STATUS: 0 = end of follow-up or death unrelated to ovarian cancer ;  1 = death due to ovarian cancer FUMND: Months from primary surgery SAMPLE NR: Unique RNA reference number///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405645/GSM405645.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405647/GSM405647.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                 title: Ovarian tumor sample 289 / Ovarian tumor sample 290///geo_accession: GSM405620 / GSM405910///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 119///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 12///characteristics_ch1.3: age: 57///characteristics_ch1.4: sample nr: 183///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405620/GSM405620.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405910/GSM405910.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                 title: Ovarian tumor sample 291 / Ovarian tumor sample 292///geo_accession: GSM405653 / GSM405799///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 120///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 37///characteristics_ch1.3: age: 69///characteristics_ch1.4: sample nr: 374///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405653/GSM405653.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405799/GSM405799.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 293 / Ovarian tumor sample 294///geo_accession: GSM405770 / GSM405850///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 16///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 15///characteristics_ch1.3: age: 55///characteristics_ch1.4: sample nr: 338///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405770/GSM405770.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405850/GSM405850.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                 title: Ovarian tumor sample 296 / Ovarian tumor sample 297///geo_accession: GSM405582 / GSM405692///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 121///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 16///characteristics_ch1.3: age: 48///characteristics_ch1.4: sample nr: 253///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405582/GSM405582.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405692/GSM405692.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                   title: Ovarian tumor sample 298 / Ovarian tumor sample 299///geo_accession: GSM405860 / GSM405921///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 17///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 2///characteristics_ch1.3: age: 70///characteristics_ch1.4: sample nr: 422///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405860/GSM405860.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405921/GSM405921.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                          title: Ovarian tumor sample 300 / Ovarian tumor sample 301///geo_accession: GSM405563 / GSM405869///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 122///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 50///characteristics_ch1.3: age: 53///characteristics_ch1.4: sample nr / sample nr///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405563/GSM405563.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405869/GSM405869.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                 title: Ovarian tumor sample 304 / Ovarian tumor sample 305///geo_accession: GSM405567 / GSM405834///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 123///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 59///characteristics_ch1.3: age: 42///characteristics_ch1.4: sample nr: 116///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405567/GSM405567.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405834/GSM405834.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                   title: Ovarian tumor sample 306 / Ovarian tumor sample 307///geo_accession: GSM405949 / GSM405960///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 124///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 19///characteristics_ch1.3: age: 48///characteristics_ch1.4: sample nr: 7///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405949/GSM405949.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405960/GSM405960.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                 title: Ovarian tumor sample 309 / Ovarian tumor sample 310///geo_accession: GSM405605 / GSM405820///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 125///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 71///characteristics_ch1.3: age: 66///characteristics_ch1.4: sample nr: 167///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405605/GSM405605.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405820/GSM405820.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                 title: Ovarian tumor sample 311 / Ovarian tumor sample 312///geo_accession: GSM405677 / GSM405687///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 126///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 29///characteristics_ch1.3: age: 42///characteristics_ch1.4: sample nr: 249///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405677/GSM405677.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405687/GSM405687.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
      title: Ovarian tumor sample 313 / Ovarian tumor sample 314///geo_accession: GSM405714 / GSM405715///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 127///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 37///characteristics_ch1.3: age: 44///characteristics_ch1.4: sample nr: 280///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics: STATUS: 0 = end of follow-up or death unrelated to ovarian cancer ;  1 = death due to ovarian cancer FUMND: Months from primary surgery SAMPLE NR: Unique RNA reference number///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405714/GSM405714.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405715/GSM405715.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                   title: Ovarian tumor sample 316 / Ovarian tumor sample 317///geo_accession: GSM405772 / GSM405818///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 128///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 9///characteristics_ch1.3: age: 42///characteristics_ch1.4: sample nr: 33///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405772/GSM405772.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405818/GSM405818.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                  title: Ovarian tumor sample 318 / Ovarian tumor sample 319///geo_accession: GSM405670 / GSM405811///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 80///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 47///characteristics_ch1.3: age: 50///characteristics_ch1.4: sample nr: 233///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405670/GSM405670.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405811/GSM405811.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                title: Ovarian tumor sample 322 / Ovarian tumor sample 323///geo_accession: GSM405738 / GSM405883///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 129///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 130///characteristics_ch1.3: age: 69///characteristics_ch1.4: sample nr: 441///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405738/GSM405738.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405883/GSM405883.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                 title: Ovarian tumor sample 324 / Ovarian tumor sample 325///geo_accession: GSM405739 / GSM405858///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 130///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 16///characteristics_ch1.3: age: 60///characteristics_ch1.4: sample nr: 420///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405739/GSM405739.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405858/GSM405858.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                 title: Ovarian tumor sample 326 / Ovarian tumor sample 327///geo_accession: GSM405560 / GSM405737///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 131///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 33///characteristics_ch1.3: age: 58///characteristics_ch1.4: sample nr: 109///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405560/GSM405560.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405737/GSM405737.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                 title: Ovarian tumor sample 328 / Ovarian tumor sample 329///geo_accession: GSM405693 / GSM405728///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 132///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 16///characteristics_ch1.3: age: 27///characteristics_ch1.4: sample nr: 292///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405693/GSM405693.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405728/GSM405728.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                    title: Ovarian tumor sample 32 / Ovarian tumor sample 33///geo_accession: GSM405694 / GSM405969///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 27///characteristics_ch1.1: status: 0///characteristics_ch1.2: fumnd: 29///characteristics_ch1.3: age: 43///characteristics_ch1.4: sample nr: 254///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy3 / Cy5///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 2 in raw data file ; Characteristics / Channel 1 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405694/GSM405694.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405969/GSM405969.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                          title: Ovarian tumor sample 331 / Ovarian tumor sample 332///geo_accession: GSM405752 / GSM405892///status: Public on May 20 2009///submission_date: May 19 2009///last_update_date: May 20 2009///type: RNA///channel_count: 1///source_name_ch1: Advanced stage serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: assigned unique patient id: 133///characteristics_ch1.1: status: 1///characteristics_ch1.2: fumnd: 22///characteristics_ch1.3: age: 61///characteristics_ch1.4: sample nr / sample nr///treatment_protocol_ch1: All tumor samples were obtained at primary surgery prior to chemotherapy.///growth_protocol_ch1: All tumor samples were flash frozen in liquid nitrogen and stored at -80 C.///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA from tumor samples was pelleted through cesium chloride density gradient ultracentrifugation (Roche, Almere, the Netherlands). After total RNA samples had been given DNAse treatment (Megascript T7 kit, Ambion, Huntingdon, UK), they were checked for residual DNA using a dinucleotide primer set D11S875 specific for genomic DNA. mRNA was linearly amplified by in vitro transcription using T7 RNA polymerase (Megascript T7 kit, Ambion, Huntingdon, UK) [13]. Quality/integrity of total and amplified mRNA (cRNA) was checked by spectrophotometer analysis, UV 260/280 ratio > 1.8, and/or agarose gel electrophoresis.///label_ch1: Cy5 / Cy3///label_protocol_ch1: All cRNA samples (1.5 g) were labeled with ULS-Cy5 and ULS-Cy3 label (BIOK, Leiden, the Netherlands).///taxid_ch1: 9606///hyb_protocol: Protocol is available at http://microarrays.nki.nl/download/protocols/Hybridization_oligo_array_ULS_labeling_of_aRNA_2005.pdf///scan_protocol: Arrays were scanned with the Affymetrix GMS428 scanner (Affymetrix, Santa Clara, CA) and expression values were calculated by BlueFuse software (BlueGnome, Cambridge, UK).///description: Channel 1 in raw data file ; Characteristics / Channel 2 in raw data file ; Characteristics///data_processing: raw data///platform_id: GPL7759///contact_name: Rudolf,Stephan Nicolaas,Fehrmann///contact_email: r.s.n.fehrmann@og.umcg.nl///contact_department: Gynecologic Oncology///contact_institute: University Medical Center Groningen///contact_address: P.O. Box 30.001///contact_city: Groningen///contact_state: Groningen///contact_zip.postal_code: 9700 RB///contact_country: Netherlands///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405752/GSM405752.xls.gz / ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM405nnn/GSM405892/GSM405892.xls.gz///data_row_count: 37632
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 (Other)
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     58

}}
\keyword{datasets}
