\name{ GSE14764 }
\alias{ GSE14764 }
\docType{data}
\title{ A prognostic gene expression index in ovarian cancer - validation across different independent data sets. }
\description{ Ovarian carcinoma has the highest mortality rate among gynaecological malignancies. In this project, we investigated the hypothesis that molecular markers are able to predict outcome of ovarian cancer independently of classical clinical predictors, and that these molecular markers can be validated using independent data sets. We applied a semi-supervised method for prediction of patient survival. Microarrays from a cohort of 80 ovarian carcinomas (TOC cohort) were used for the development of a predictive model, which was then evaluated in an entirely independent cohort of 118 carcinomas (Duke cohort). A 300-gene ovarian prognostic index (OPI) was generated and validated in a leave-one-out approach in the TOC cohort (Kaplan-Meier analysis, p = 0.0087). In a second validation step, the prognostic power of the OPI was confirmed in an independent data set (Duke cohort, p = 0.0063). In multivariate analysis, the OPI was independent of the post-operative residual tumour, the main clinico-pathological prognostic parameter with an adjusted hazard ratio of 6.4 (TOC cohort, CI 1.8-23.5, p = 0.0049) and 1.9 (Duke cohort, CI 1.2-3.0, p = 0.0068). We constructed a combined score of molecular data (OPI) and clinical parameters (residual tumour), which was able to define patient groups with highly significant differences in survival. The integrated analysis of gene expression data as well as residual tumour can be used for optimized assessment of the prognosis of platinum-taxol-treated ovarian cancer. As traditional treatment options are limited, this analysis may be able to optimize clinical management and to identify those patients who would be candidates for new therapeutic strategies. }
\value{An expression set}
\format{
\preformatted{
experimentData(eset):
Experiment data
  Experimenter name: Denkert C, Budczies J, Darb-Esfahani S, Gy??rffy B et al. A prognostic gene expression index in ovarian cancer - validation across different independent data sets. J Pathol 2009 Jun;218(2):273-80.
  Laboratory: Denkert, Lage 2009
  Contact information:
  Title: A prognostic gene expression index in ovarian cancer - validation across different independent data sets.
  URL:
  PMIDs: 19294737

  Abstract: A 254 word abstract is available. Use 'abstract' method.
  Information is available on: preprocessing
  notes:
   platform_title:
      [HG-U133A] Affymetrix Human Genome U133A Array
   platform_shorttitle:
      Affymetrix HG-U133A
   platform_summary:
      hgu133a
   platform_manufacturer:
      Affymetrix
   platform_distribution:
      commercial
   platform_accession:
      GPL96
   version:
      2015-09-22 19:13:08

featureData(eset):
An object of class 'AnnotatedDataFrame'
  featureNames: 1007_s_at 1053_at ... AFFX-HUMISGF3A/M97935_MB_at
    (20967 total)
  varLabels: probeset gene EntrezGene.ID best_probe
  varMetadata: labelDescription

}}
\details{
\preformatted{
assayData: 20967 features, 80 samples
Platform type:
Overall survival time-to-event summary (in years):
Call: survfit(formula = Surv(time, cens) ~ -1)

      n  events  median 0.95LCL 0.95UCL
  80.00   21.00    4.52    4.19      NA

---------------------------
Available sample meta-data:
---------------------------

alt_sample_name:
   Min. 1st Qu.  Median    Mean 3rd Qu.    Max.
   1.00   20.75   40.50   40.50   60.25   80.00

sample_type:
tumor
   80

histological_type:
       clearcell             endo              mix            other
               2                6                1                2
             ser undifferentiated
              68                1

primarysite:
ov
80

summarygrade:
high  low
  54   26

summarystage:
early  late
    9    71

tumorstage:
 1  2  3  4
 8  1 69  2

substage:
   a    b    c NA's
   4    6   32   38

grade:
 1  2  3
 3 23 54

recurrence_status:
norecurrence   recurrence         NA's
          50           26            4

days_to_death:
   Min. 1st Qu.  Median    Mean 3rd Qu.    Max.
    210     660    1050    1011    1328    2190

vital_status:
deceased   living
      21       59

batch:
2004-09-29 2004-09-30 2004-10-01 2005-01-21 2005-01-25 2005-01-26 2005-01-28
         1          2          6          4          7          8         10
2005-03-02 2006-07-26 2006-07-27 2006-07-28 2006-08-11 2006-08-18 2006-08-19
         6          4          6          4         10          3          4
2006-08-21
         5

uncurated_author_metadata:
              title: ovarian cancer: O10///geo_accession: GSM368670///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 35///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368670/GSM368670.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
              title: ovarian cancer: O11///geo_accession: GSM368671///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 54///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368671/GSM368671.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
            title: ovarian cancer: O12///geo_accession: GSM368672///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: endometr ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 68///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368672/GSM368672.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
              title: ovarian cancer: O13///geo_accession: GSM368673///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 40///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368673/GSM368673.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O14///geo_accession: GSM368674///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 18///characteristics_ch1.6: overall survival event: 1///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368674/GSM368674.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
             title: ovarian cancer: O15///geo_accession: GSM368675///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: NA///characteristics_ch1.5: overall survival time: 30///characteristics_ch1.6: overall survival event: 1///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368675/GSM368675.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
           title: ovarian cancer: O16///geo_accession: GSM368676///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 1a///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: clear cell ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 45///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368676/GSM368676.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
              title: ovarian cancer: O17///geo_accession: GSM368677///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 2b///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 40///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368677/GSM368677.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
              title: ovarian cancer: O18///geo_accession: GSM368678///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 67///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368678/GSM368678.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
              title: ovarian cancer: O19///geo_accession: GSM368679///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 31///characteristics_ch1.6: overall survival event: 1///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368679/GSM368679.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                title: ovarian cancer: O1///geo_accession: GSM368661///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 4///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 39///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368661/GSM368661.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O20///geo_accession: GSM368680///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 38///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368680/GSM368680.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
              title: ovarian cancer: O21///geo_accession: GSM368681///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 43///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368681/GSM368681.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
              title: ovarian cancer: O22///geo_accession: GSM368682///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 1c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 29///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368682/GSM368682.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
              title: ovarian cancer: O23///geo_accession: GSM368683///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 12///characteristics_ch1.6: overall survival event: 1///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368683/GSM368683.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
          title: ovarian cancer: O24///geo_accession: GSM368684///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 1c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: clear cell ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 51///characteristics_ch1.6: overall survival event: 1///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368684/GSM368684.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
              title: ovarian cancer: O25///geo_accession: GSM368685///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 40///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368685/GSM368685.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: ovarian cancer: O26///geo_accession: GSM368686///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 1a///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: endometr, clear cell ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 37///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368686/GSM368686.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
            title: ovarian cancer: O27///geo_accession: GSM368687///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 1b///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: endometr ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 49///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368687/GSM368687.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
            title: ovarian cancer: O28///geo_accession: GSM368688///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 1c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: endometr ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 36///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368688/GSM368688.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
             title: ovarian cancer: O29///geo_accession: GSM368689///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: NA///characteristics_ch1.5: overall survival time: 49///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368689/GSM368689.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O2///geo_accession: GSM368662///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 35///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368662/GSM368662.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
              title: ovarian cancer: O30///geo_accession: GSM368690///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: NA///characteristics_ch1.5: overall survival time: 46///characteristics_ch1.6: overall survival event: 1///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368690/GSM368690.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
              title: ovarian cancer: O31///geo_accession: GSM368691///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 20///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368691/GSM368691.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
              title: ovarian cancer: O32///geo_accession: GSM368692///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 37///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368692/GSM368692.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O33///geo_accession: GSM368693///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3b///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 37///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368693/GSM368693.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
              title: ovarian cancer: O34///geo_accession: GSM368694///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3b///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 40///characteristics_ch1.6: overall survival event: 1///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368694/GSM368694.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
              title: ovarian cancer: O35///geo_accession: GSM368695///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 47///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368695/GSM368695.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O36///geo_accession: GSM368696///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3b///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 42///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368696/GSM368696.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O37///geo_accession: GSM368697///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 52///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368697/GSM368697.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
             title: ovarian cancer: O38///geo_accession: GSM368698///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: NA///characteristics_ch1.5: overall survival time: 22///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368698/GSM368698.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
              title: ovarian cancer: O39///geo_accession: GSM368699///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 45///characteristics_ch1.6: overall survival event: 1///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368699/GSM368699.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
      title: ovarian cancer: O3///geo_accession: GSM368663///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3b///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: transitional cell ca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 27///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368663/GSM368663.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
              title: ovarian cancer: O40///geo_accession: GSM368700///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 20///characteristics_ch1.6: overall survival event: 1///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368700/GSM368700.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O41///geo_accession: GSM368701///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 45///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368701/GSM368701.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
             title: ovarian cancer: O42///geo_accession: GSM368702///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 4///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: endometr ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 32///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368702/GSM368702.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
              title: ovarian cancer: O43///geo_accession: GSM368703///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 49///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368703/GSM368703.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O44///geo_accession: GSM368704///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 15///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368704/GSM368704.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                title: ovarian cancer: O45///geo_accession: GSM368705///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 43///characteristics_ch1.6: overall survival event: 1///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368705/GSM368705.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                 title: ovarian cancer: O46///geo_accession: GSM368706///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: I///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 73///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368706/GSM368706.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O47///geo_accession: GSM368707///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 53///characteristics_ch1.6: overall survival event: 1///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368707/GSM368707.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                 title: ovarian cancer: O48///geo_accession: GSM368708///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: I///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 38///characteristics_ch1.6: overall survival event: 1///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368708/GSM368708.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O49///geo_accession: GSM368709///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 51///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368709/GSM368709.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O4///geo_accession: GSM368664///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 14///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368664/GSM368664.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O50///geo_accession: GSM368710///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 55///characteristics_ch1.6: overall survival event: 1///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368710/GSM368710.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                title: ovarian cancer: O51///geo_accession: GSM368711///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 27///characteristics_ch1.6: overall survival event: 1///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368711/GSM368711.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
              title: ovarian cancer: O52///geo_accession: GSM368712///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: endometr ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 7///characteristics_ch1.6: overall survival event: 1///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368712/GSM368712.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                title: ovarian cancer: O53///geo_accession: GSM368713///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 44///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368713/GSM368713.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O54///geo_accession: GSM368714///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 22///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368714/GSM368714.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O55///geo_accession: GSM368715///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 36///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368715/GSM368715.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                title: ovarian cancer: O56///geo_accession: GSM368716///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 35///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368716/GSM368716.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                title: ovarian cancer: O57///geo_accession: GSM368717///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 34///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368717/GSM368717.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O58///geo_accession: GSM368718///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: sarcomatoid///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 34///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368718/GSM368718.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                title: ovarian cancer: O59///geo_accession: GSM368719///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 23///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368719/GSM368719.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O5///geo_accession: GSM368665///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 46///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368665/GSM368665.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O60///geo_accession: GSM368720///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 24///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368720/GSM368720.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O61///geo_accession: GSM368721///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 25///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368721/GSM368721.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O62///geo_accession: GSM368722///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 25///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368722/GSM368722.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O63///geo_accession: GSM368723///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 21///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368723/GSM368723.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O64///geo_accession: GSM368724///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 12///characteristics_ch1.6: overall survival event: 1///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368724/GSM368724.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O65///geo_accession: GSM368725///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 13///characteristics_ch1.6: overall survival event: 1///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368725/GSM368725.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                title: ovarian cancer: O66///geo_accession: GSM368726///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 7///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368726/GSM368726.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                title: ovarian cancer: O67///geo_accession: GSM368727///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 10///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368727/GSM368727.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O68///geo_accession: GSM368728///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 20///characteristics_ch1.6: overall survival event: 1///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368728/GSM368728.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                title: ovarian cancer: O69///geo_accession: GSM368729///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 58///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368729/GSM368729.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                title: ovarian cancer: O6///geo_accession: GSM368666///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 37///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368666/GSM368666.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                title: ovarian cancer: O70///geo_accession: GSM368730///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 13///characteristics_ch1.6: overall survival event: 1///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368730/GSM368730.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                title: ovarian cancer: O71///geo_accession: GSM368731///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 8///characteristics_ch1.6: overall survival event: 1///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368731/GSM368731.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O72///geo_accession: GSM368732///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 15///characteristics_ch1.6: overall survival event: 1///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368732/GSM368732.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
     title: ovarian cancer: O73///geo_accession: GSM368733///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: undifferentiated ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 27///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368733/GSM368733.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O74///geo_accession: GSM368734///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 23///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368734/GSM368734.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                title: ovarian cancer: O75///geo_accession: GSM368735///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 29///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368735/GSM368735.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O76///geo_accession: GSM368736///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 25///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368736/GSM368736.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O77///geo_accession: GSM368737///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 20///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368737/GSM368737.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                title: ovarian cancer: O78///geo_accession: GSM368738///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 23///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368738/GSM368738.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                title: ovarian cancer: O79///geo_accession: GSM368739///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 24///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368739/GSM368739.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O7///geo_accession: GSM368667///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 1a///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 36///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368667/GSM368667.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                title: ovarian cancer: O80///geo_accession: GSM368740///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3///characteristics_ch1.2: grade: II///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 1///characteristics_ch1.5: overall survival time: 21///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368740/GSM368740.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O8///geo_accession: GSM368668///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 3c///characteristics_ch1.2: grade: III///characteristics_ch1.3: histological type: serous ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 12///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368668/GSM368668.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
               title: ovarian cancer: O9///geo_accession: GSM368669///status: Public on Feb 09 2009///submission_date: Feb 09 2009///last_update_date: Aug 24 2010///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: frozen tumor///characteristics_ch1.1: figo stage: 1a///characteristics_ch1.2: grade: I///characteristics_ch1.3: histological type: endometr ovca///characteristics_ch1.4: residual tumor: 0///characteristics_ch1.5: overall survival time: 70///characteristics_ch1.6: overall survival event: 0///molecule_ch1: total RNA///extract_protocol_ch1: Total cellular RNA was isolated from tumor tissue, using the Qiagen Rneasy Mini Kit.///label_ch1: biotin///label_protocol_ch1: cDNA was synthesised from 5 g total RNA by reverse transcription, synthesis of biotin-labeled cRNA was performed using the BioArray High Yield RNA Transcription kit.///taxid_ch1: 9606///hyb_protocol: The fragmented cRNA was hybridised to HGU133 arrays at 45 C in a hybridization oven for 16 hr.///scan_protocol: Chip scanning was done with an Affymetrix Gene Array Scanner G2500A.///description: frozen tissue sample///data_processing: Signals and detection calls were calculated with the R package affy according to the standard MAS 5.0 protocol of the chip manufacturer.///platform_id: GPL96///contact_name: Jan,,Budczies///contact_email: jan.budczies@charite.de///contact_department: Institute of Pathology///contact_institute: Charite - Universitaetsmedizin Berlin///contact_address: Chariteplatz 2///contact_city: Berlin///contact_zip.postal_code: 10117///contact_country: Germany///contact_web_link: http://www.charite.de/ch/patho///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM368nnn/GSM368669/GSM368669.cel.gz///data_row_count: 22283
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1

duplicates:
GSE14764.GSE14764_GSM368667 GSE14764.GSE14764_GSM368668
                          1                           1
                       NA's
                         78

}}
\keyword{datasets}
