\name{ GSE20565 }
\alias{ GSE20565 }
\docType{data}
\title{ A genomic and transcriptomic approach for a differential diagnosis between primary and secondary ovarian carcinomas in patients with a previous history of breast cancer. }
\description{ The distinction between primary and secondary ovarian tumors may be challenging for pathologists. The purpose of the present work was to develop genomic and transcriptomic tools to further refine the pathological diagnosis of ovarian tumors after a previous history of breast cancer.Sixteen paired breast-ovary tumors from patients with a former diagnosis of breast cancer were collected. The genomic profiles of paired tumors were analyzed using the Affymetrix GeneChip Mapping 50 K Xba Array or Genome-Wide Human SNP Array 6.0 (for one pair), and the data were normalized with ITALICS (ITerative and Alternative normaLIzation and Copy number calling for affymetrix Snp arrays) algorithm or Partek Genomic Suite, respectively. The transcriptome of paired samples was analyzed using Affymetrix GeneChip Human Genome U133 Plus 2.0 Arrays, and the data were normalized with gc-Robust Multi-array Average (gcRMA) algorithm. A hierarchical clustering of these samples was performed, combined with a dataset of well-identified primary and secondary ovarian tumors.In 12 of the 16 paired tumors analyzed, the comparison of genomic profiles confirmed the pathological diagnosis of primary ovarian tumor (n = 5) or metastasis of breast cancer (n = 7). Among four cases with uncertain pathological diagnosis, genomic profiles were clearly distinct between the ovarian and breast tumors in two pairs, thus indicating primary ovarian carcinomas, and showed common patterns in the two others, indicating metastases from breast cancer. In all pairs, the result of the transcriptomic analysis was concordant with that of the genomic analysis.In patients with ovarian carcinoma and a previous history of breast cancer, SNP array analysis can be used to distinguish primary and secondary ovarian tumors. Transcriptomic analysis may be used when primary breast tissue specimen is not available. }
\value{An expression set}
\format{
\preformatted{
experimentData(eset):
Experiment data
  Experimenter name: Meyniel JP, Cottu PH, Decraene C, Stern MH, Couturier J, Lebigot I, Nicolas A, Weber N, Fourchotte V, Alran S, Rapinat A, Gentien D, Roman-Roman S, Mignot L, Sastre-Garau X.A genomic and transcriptomic approach for a differential diagnosis between primary and secondary ovarian carcinomas in patients with a previous history of breast cancer. BMC Cancer. 2010 May 21; 10:222.
  Laboratory: Meyniel, Sastre-Garau 2010
  Contact information:
  Title: A genomic and transcriptomic approach for a differential diagnosis between primary and secondary ovarian carcinomas in patients with a previous history of breast cancer.
  URL:
  PMIDs: 20492709

  Abstract: A 277 word abstract is available. Use 'abstract' method.
  Information is available on: preprocessing
  notes:
   platform_title:
      [HG-U133_Plus_2] Affymetrix Human Genome U133 Plus 2.0 Array
   platform_shorttitle:
      Affymetrix HG-U133Plus2
   platform_summary:
      hgu133plus2
   platform_manufacturer:
      Affymetrix
   platform_distribution:
      commercial
   platform_accession:
      GPL570|GPL2005|GPL6801
   version:
      2015-09-22 19:33:01

featureData(eset):
An object of class 'AnnotatedDataFrame'
  featureNames: 1007_s_at 1053_at ... AFFX-HUMISGF3A/M97935_MB_at
    (42447 total)
  varLabels: probeset gene EntrezGene.ID best_probe
  varMetadata: labelDescription

}}
\details{
\preformatted{
assayData: 42447 features, 140 samples
Platform type:
---------------------------
Available sample meta-data:
---------------------------

alt_sample_name:
Breast metastasis in the ovary_OC01_ARN0016 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0017 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0020 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0029 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0035 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0046 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0051 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0053 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0055 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0060 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0069 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0073 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0077 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0079 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0081 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0083 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0092 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0097 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0098 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0099 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0102 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0104 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0112 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0120 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0121 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0123 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0126 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0141 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0142 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0143 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0145 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0146 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0153 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0162 [HG-U133_Plus_2]
                                                           1
Breast metastasis in the ovary_OC01_ARN0201 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0001 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0002 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0004 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0005 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0007 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0008 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0009 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0010 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0011 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0012 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0013 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0015 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0022 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0023 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0025 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0028 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0030 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0032 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0034 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0036 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0037 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0038 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0039 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0041 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0042 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0045 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0049 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0057 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0058 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0061 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0062 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0063 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0064 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0066 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0067 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0070 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0072 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0075 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0076 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0080 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0084 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0085 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0089 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0091 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0093 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0095 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0096 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0100 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0101 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0103 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0105 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0106 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0107 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0108 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0109 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0111 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0113 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0114 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0115 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0116 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0118 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0119 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0124 [HG-U133_Plus_2]
                                                           1
             Ovarian carcinoma_OC01_ARN0125 [HG-U133_Plus_2]
                                                           1
                                                     (Other)
                                                          41

sample_type:
tumor
  140

histological_type:
clearcell      endo  mucinous     other       ser      NA's
        6         6         7         6        71        44

primarysite:
other    ov
   44    96

summarygrade:
high  low NA's
  63   33   44

summarystage:
early  late  NA's
   27    67    46

tumorstage:
   1    2    3    4 NA's
  18    9   52   15   46

substage:
   a    b    c NA's
  14   10   55   61

grade:
   1    2    3 NA's
   6   27   63   44

batch:
2006-06-01 2006-06-27 2006-06-28 2006-06-29 2006-06-30 2006-07-20 2008-03-06
        21         18         37         20         36          7          1

uncurated_author_metadata:
title: Breast metastasis in the ovary_OC01_ARN0016 [HG-U133_Plus_2]///geo_accession: GSM516692///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0016///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516692/GSM516692.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0017 [HG-U133_Plus_2]///geo_accession: GSM516693///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0017///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516693/GSM516693.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0020 [HG-U133_Plus_2]///geo_accession: GSM516695///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0020///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516695/GSM516695.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0029 [HG-U133_Plus_2]///geo_accession: GSM516701///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0029///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516701/GSM516701.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0035 [HG-U133_Plus_2]///geo_accession: GSM516705///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0035///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516705/GSM516705.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0046 [HG-U133_Plus_2]///geo_accession: GSM516714///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0046///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516714/GSM516714.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0051 [HG-U133_Plus_2]///geo_accession: GSM516716///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0051///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516716/GSM516716.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0053 [HG-U133_Plus_2]///geo_accession: GSM516717///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0053///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516717/GSM516717.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0055 [HG-U133_Plus_2]///geo_accession: GSM516718///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0055///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516718/GSM516718.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0060 [HG-U133_Plus_2]///geo_accession: GSM516722///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0060///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516722/GSM516722.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0069 [HG-U133_Plus_2]///geo_accession: GSM516729///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0069///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516729/GSM516729.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0073 [HG-U133_Plus_2]///geo_accession: GSM516732///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0073///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516732/GSM516732.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0077 [HG-U133_Plus_2]///geo_accession: GSM516736///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0077///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516736/GSM516736.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0079 [HG-U133_Plus_2]///geo_accession: GSM516738///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0079///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516738/GSM516738.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0081 [HG-U133_Plus_2]///geo_accession: GSM516740///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0081///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516740/GSM516740.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0083 [HG-U133_Plus_2]///geo_accession: GSM516741///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0083///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516741/GSM516741.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0092 [HG-U133_Plus_2]///geo_accession: GSM516748///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0092///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516748/GSM516748.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0097 [HG-U133_Plus_2]///geo_accession: GSM516752///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0097///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516752/GSM516752.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0098 [HG-U133_Plus_2]///geo_accession: GSM516753///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0098///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516753/GSM516753.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0099 [HG-U133_Plus_2]///geo_accession: GSM516754///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0099///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516754/GSM516754.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0102 [HG-U133_Plus_2]///geo_accession: GSM516757///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0102///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516757/GSM516757.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0104 [HG-U133_Plus_2]///geo_accession: GSM516759///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0104///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516759/GSM516759.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0112 [HG-U133_Plus_2]///geo_accession: GSM516766///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0112///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516766/GSM516766.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0120 [HG-U133_Plus_2]///geo_accession: GSM516773///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0120///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516773/GSM516773.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0121 [HG-U133_Plus_2]///geo_accession: GSM516774///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0121///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516774/GSM516774.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0123 [HG-U133_Plus_2]///geo_accession: GSM516775///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0123///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516775/GSM516775.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0126 [HG-U133_Plus_2]///geo_accession: GSM516778///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0126///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516778/GSM516778.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0141 [HG-U133_Plus_2]///geo_accession: GSM516790///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0141///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516790/GSM516790.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0142 [HG-U133_Plus_2]///geo_accession: GSM516791///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0142///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516791/GSM516791.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0143 [HG-U133_Plus_2]///geo_accession: GSM516792///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0143///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516792/GSM516792.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0145 [HG-U133_Plus_2]///geo_accession: GSM516793///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0145///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516793/GSM516793.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0146 [HG-U133_Plus_2]///geo_accession: GSM516794///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0146///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516794/GSM516794.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0153 [HG-U133_Plus_2]///geo_accession: GSM516800///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0153///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516800/GSM516800.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0162 [HG-U133_Plus_2]///geo_accession: GSM516809///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0162///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516809/GSM516809.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Breast metastasis in the ovary_OC01_ARN0201 [HG-U133_Plus_2]///geo_accession: GSM516810///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Breast metastasis in the ovary///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Breast metastasis in the ovary///characteristics_ch1.2: identifier: OC01_ARN0201///characteristics_ch1.3: histotype: N/A///characteristics_ch1.4: tumor/metastasis: M///characteristics_ch1.5: grade: N/A///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from breast metastasis in the ovary///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516810/GSM516810.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                    title: Ovarian carcinoma_OC01_ARN0001 [HG-U133_Plus_2]///geo_accession: GSM516678///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0001///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: Ib///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516678/GSM516678.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                             title: Ovarian carcinoma_OC01_ARN0002 [HG-U133_Plus_2]///geo_accession: GSM516679///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0002///characteristics_ch1.3: histotype: Endometrioid///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: IIb///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516679/GSM516679.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0004 [HG-U133_Plus_2]///geo_accession: GSM516680///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0004///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516680/GSM516680.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                    title: Ovarian carcinoma_OC01_ARN0005 [HG-U133_Plus_2]///geo_accession: GSM516681///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0005///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IV///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516681/GSM516681.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0007 [HG-U133_Plus_2]///geo_accession: GSM516683///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0007///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516683/GSM516683.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0008 [HG-U133_Plus_2]///geo_accession: GSM516684///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0008///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516684/GSM516684.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0009 [HG-U133_Plus_2]///geo_accession: GSM516685///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0009///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516685/GSM516685.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                   title: Ovarian carcinoma_OC01_ARN0010 [HG-U133_Plus_2]///geo_accession: GSM516686///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0010///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: N/A///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516686/GSM516686.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                    title: Ovarian carcinoma_OC01_ARN0011 [HG-U133_Plus_2]///geo_accession: GSM516687///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0011///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: Ib///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516687/GSM516687.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                    title: Ovarian carcinoma_OC01_ARN0012 [HG-U133_Plus_2]///geo_accession: GSM516688///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0012///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 1///characteristics_ch1.6: stade: Ib///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516688/GSM516688.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                title: Ovarian carcinoma_OC01_ARN0013 [HG-U133_Plus_2]///geo_accession: GSM516689///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0013///characteristics_ch1.3: histotype: Mucinous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516689/GSM516689.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                    title: Ovarian carcinoma_OC01_ARN0015 [HG-U133_Plus_2]///geo_accession: GSM516691///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0015///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IV///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516691/GSM516691.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                    title: Ovarian carcinoma_OC01_ARN0022 [HG-U133_Plus_2]///geo_accession: GSM516697///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0022///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: Ia///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516697/GSM516697.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                    title: Ovarian carcinoma_OC01_ARN0023 [HG-U133_Plus_2]///geo_accession: GSM516698///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0023///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IV///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516698/GSM516698.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                    title: Ovarian carcinoma_OC01_ARN0025 [HG-U133_Plus_2]///geo_accession: GSM516699///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0025///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IV///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516699/GSM516699.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                    title: Ovarian carcinoma_OC01_ARN0028 [HG-U133_Plus_2]///geo_accession: GSM516700///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0028///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 1///characteristics_ch1.6: stade: IV///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516700/GSM516700.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                            title: Ovarian carcinoma_OC01_ARN0030 [HG-U133_Plus_2]///geo_accession: GSM516702///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0030///characteristics_ch1.3: histotype: Endometrioid///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516702/GSM516702.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0032 [HG-U133_Plus_2]///geo_accession: GSM516703///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0032///characteristics_ch1.3: histotype: Mucinous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: Ia///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516703/GSM516703.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0034 [HG-U133_Plus_2]///geo_accession: GSM516704///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0034///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516704/GSM516704.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                    title: Ovarian carcinoma_OC01_ARN0036 [HG-U133_Plus_2]///geo_accession: GSM516706///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0036///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: Ic///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516706/GSM516706.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0037 [HG-U133_Plus_2]///geo_accession: GSM516707///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0037///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516707/GSM516707.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0038 [HG-U133_Plus_2]///geo_accession: GSM516708///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0038///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516708/GSM516708.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0039 [HG-U133_Plus_2]///geo_accession: GSM516709///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0039///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516709/GSM516709.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                             title: Ovarian carcinoma_OC01_ARN0041 [HG-U133_Plus_2]///geo_accession: GSM516711///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0041///characteristics_ch1.3: histotype: Clear Cells///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: IIIb///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516711/GSM516711.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0042 [HG-U133_Plus_2]///geo_accession: GSM516712///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0042///characteristics_ch1.3: histotype: Mucinous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 1///characteristics_ch1.6: stade: Ia///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516712/GSM516712.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                            title: Ovarian carcinoma_OC01_ARN0045 [HG-U133_Plus_2]///geo_accession: GSM516713///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0045///characteristics_ch1.3: histotype: Adenocarcinoma///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IV///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516713/GSM516713.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0049 [HG-U133_Plus_2]///geo_accession: GSM516715///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0049///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516715/GSM516715.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0057 [HG-U133_Plus_2]///geo_accession: GSM516720///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0057///characteristics_ch1.3: histotype: Mucinous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: Ic///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516720/GSM516720.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                               title: Ovarian carcinoma_OC01_ARN0058 [HG-U133_Plus_2]///geo_accession: GSM516721///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0058///characteristics_ch1.3: histotype: Clear Cells///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: Ic///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516721/GSM516721.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0061 [HG-U133_Plus_2]///geo_accession: GSM516723///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0061///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516723/GSM516723.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0062 [HG-U133_Plus_2]///geo_accession: GSM516724///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0062///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516724/GSM516724.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0063 [HG-U133_Plus_2]///geo_accession: GSM516725///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0063///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516725/GSM516725.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                    title: Ovarian carcinoma_OC01_ARN0064 [HG-U133_Plus_2]///geo_accession: GSM516726///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0064///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IV///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516726/GSM516726.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0066 [HG-U133_Plus_2]///geo_accession: GSM516727///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0066///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516727/GSM516727.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0067 [HG-U133_Plus_2]///geo_accession: GSM516728///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0067///characteristics_ch1.3: histotype: Mucinous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: Ic///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516728/GSM516728.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0070 [HG-U133_Plus_2]///geo_accession: GSM516730///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0070///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516730/GSM516730.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                   title: Ovarian carcinoma_OC01_ARN0072 [HG-U133_Plus_2]///geo_accession: GSM516731///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0072///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: IIb///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516731/GSM516731.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0075 [HG-U133_Plus_2]///geo_accession: GSM516734///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0075///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516734/GSM516734.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                           title: Ovarian carcinoma_OC01_ARN0076 [HG-U133_Plus_2]///geo_accession: GSM516735///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0076///characteristics_ch1.3: histotype: Brenner Tumor///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516735/GSM516735.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0080 [HG-U133_Plus_2]///geo_accession: GSM516739///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0080///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516739/GSM516739.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0084 [HG-U133_Plus_2]///geo_accession: GSM516742///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0084///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516742/GSM516742.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                               title: Ovarian carcinoma_OC01_ARN0085 [HG-U133_Plus_2]///geo_accession: GSM516743///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0085///characteristics_ch1.3: histotype: Clear Cells///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: Ia///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516743/GSM516743.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0089 [HG-U133_Plus_2]///geo_accession: GSM516745///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0089///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516745/GSM516745.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                           title: Ovarian carcinoma_OC01_ARN0091 [HG-U133_Plus_2]///geo_accession: GSM516747///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0091///characteristics_ch1.3: histotype: Adenocarcinoma///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIa///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516747/GSM516747.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0093 [HG-U133_Plus_2]///geo_accession: GSM516749///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0093///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516749/GSM516749.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0095 [HG-U133_Plus_2]///geo_accession: GSM516750///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0095///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: IIIb///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516750/GSM516750.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                title: Ovarian carcinoma_OC01_ARN0096 [HG-U133_Plus_2]///geo_accession: GSM516751///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0096///characteristics_ch1.3: histotype: Mucinous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 1///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516751/GSM516751.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                   title: Ovarian carcinoma_OC01_ARN0100 [HG-U133_Plus_2]///geo_accession: GSM516755///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0100///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIb///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516755/GSM516755.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                               title: Ovarian carcinoma_OC01_ARN0101 [HG-U133_Plus_2]///geo_accession: GSM516756///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0101///characteristics_ch1.3: histotype: Clear Cells///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IV///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516756/GSM516756.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0103 [HG-U133_Plus_2]///geo_accession: GSM516758///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0103///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516758/GSM516758.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0105 [HG-U133_Plus_2]///geo_accession: GSM516760///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0105///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516760/GSM516760.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0106 [HG-U133_Plus_2]///geo_accession: GSM516761///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0106///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516761/GSM516761.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0107 [HG-U133_Plus_2]///geo_accession: GSM516762///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0107///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516762/GSM516762.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0108 [HG-U133_Plus_2]///geo_accession: GSM516763///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0108///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516763/GSM516763.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                              title: Ovarian carcinoma_OC01_ARN0109 [HG-U133_Plus_2]///geo_accession: GSM516764///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0109///characteristics_ch1.3: histotype: Clear Cells///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: IIa///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516764/GSM516764.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0111 [HG-U133_Plus_2]///geo_accession: GSM516765///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0111///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516765/GSM516765.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                             title: Ovarian carcinoma_OC01_ARN0113 [HG-U133_Plus_2]///geo_accession: GSM516767///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0113///characteristics_ch1.3: histotype: Endometrioid///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 1///characteristics_ch1.6: stade: IIa///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516767/GSM516767.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                          title: Ovarian carcinoma_OC01_ARN0114 [HG-U133_Plus_2]///geo_accession: GSM516768///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0114///characteristics_ch1.3: histotype: Carcinosarcoma///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516768/GSM516768.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                              title: Ovarian carcinoma_OC01_ARN0115 [HG-U133_Plus_2]///geo_accession: GSM516769///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0115///characteristics_ch1.3: histotype: Endometrioid///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: Ia///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516769/GSM516769.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                    title: Ovarian carcinoma_OC01_ARN0116 [HG-U133_Plus_2]///geo_accession: GSM516770///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0116///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: IV///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516770/GSM516770.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0118 [HG-U133_Plus_2]///geo_accession: GSM516771///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0118///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 2///characteristics_ch1.6: stade: IIIa///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516771/GSM516771.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0119 [HG-U133_Plus_2]///geo_accession: GSM516772///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0119///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516772/GSM516772.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0124 [HG-U133_Plus_2]///geo_accession: GSM516776///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0124///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516776/GSM516776.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                  title: Ovarian carcinoma_OC01_ARN0125 [HG-U133_Plus_2]///geo_accession: GSM516777///status: Public on Apr 14 2010///submission_date: Mar 01 2010///last_update_date: Apr 14 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian carcinoma///organism_ch1: Homo sapiens///characteristics_ch1: tissue: Ovary///characteristics_ch1.1: histology (disease state): Ovarian carcinoma///characteristics_ch1.2: identifier: OC01_ARN0125///characteristics_ch1.3: histotype: Serous///characteristics_ch1.4: tumor/metastasis: T///characteristics_ch1.5: grade: 3///characteristics_ch1.6: stade: IIIc///treatment_protocol_ch1: N/A///growth_protocol_ch1: N/A///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA purification was conducted using miRNeasy kit///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 2 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix)_mRNA.///taxid_ch1: 9606///hyb_protocol: Following fragmentation, 10 ug of cRNA were hybridized for 16 hr at 45C on GeneChip U133 plus 2,0 Genome Array. GeneChips were washed and stained in the Affymetrix Fluidics Station 450.///scan_protocol: GeneChips were scanned using the Affymetrix 7G Scanner GCS3000///description: Gene expression data from ovarian carcinoma///data_processing: The data were processed/analyzed with gc-RMA (Partek Genomic Suite 6.09.1008).///platform_id: GPL570///contact_name: Jean-Philippe,,MEYNIEL///contact_email: jean-philippe.meyniel@curie.fr///contact_phone: 33153194126///contact_fax: 33153194130///contact_department: Translational Research Dept///contact_institute: Institut Curie///contact_address: 26, rue d'Ulm///contact_city: PARIS///contact_zip.postal_code: 75248///contact_country: France///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM516nnn/GSM516777/GSM516777.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         (Other)
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     41

duplicates:
GSE20565.GSE20565_GSM516722 GSE20565.GSE20565_GSM516741
                          1                           1
                       NA's
                        138

}}
\keyword{datasets}
