\name{ GSE30161 }
\alias{ GSE30161 }
\docType{data}
\title{ Multi-gene expression predictors of single drug responses to adjuvant chemotherapy in ovarian carcinoma: predicting platinum resistance. }
\description{ Despite advances in radical surgery and chemotherapy delivery, ovarian cancer is the most lethal gynecologic malignancy. Standard therapy includes treatment with platinum-based combination chemotherapies yet there is no biomarker model to predict their responses to these agents. We here have developed and independently tested our multi-gene molecular predictors for forecasting patients' responses to individual drugs on a cohort of 55 ovarian cancer patients. To independently validate these molecular predictors, we performed microarray profiling on FFPE tumor samples of 55 ovarian cancer patients (UVA-55) treated with platinum-based adjuvant chemotherapy. Genome-wide chemosensitivity biomarkers were initially discovered from the in vitro drug activities and genomic expression data for carboplatin and paclitaxel, respectively. Multivariate predictors were trained with the cell line data and then evaluated with a historical patient cohort. For the UVA-55 cohort, the carboplatin, taxol, and combination predictors significantly stratified responder patients and non-responder patients (p = 0.019, 0.04, 0.014) with sensitivity = 91\%, 96\%, 93 and NPV = 57\%, 67\%, 67\% in pathologic clinical response. The combination predictor also demonstrated a significant survival difference between predicted responders and non-responders with a median survival of 55.4 months vs. 32.1 months. Thus, COXEN single- and combination-drug predictors successfully stratified platinum resistance and taxane response in an independent cohort of ovarian cancer patients based on their FFPE tumor samples. }
\value{An expression set}
\format{
\preformatted{
experimentData(eset):
Experiment data
  Experimenter name: Ferriss JS, Kim Y, Duska L, Birrer M, Levine DA, Moskaluk C,Theodorescu D, Lee JK
  Laboratory: Ferriss, Lee 2012
  Contact information:
  Title: Multi-gene expression predictors of single drug responses to adjuvant chemotherapy in ovarian carcinoma: predicting platinum resistance.
  URL:
  PMIDs: 22348014

  Abstract: A 215 word abstract is available. Use 'abstract' method.
  Information is available on: preprocessing
  notes:
   platform_title:
      [HG-U133_Plus_2] Affymetrix Human Genome U133 Plus 2.0 Array
   platform_shorttitle:
      Affymetrix HG-U133Plus2
   platform_summary:
      hgu133plus2
   platform_manufacturer:
      Affymetrix
   platform_distribution:
      commercial
   platform_accession:
      GPL570
   version:
      2015-09-22 19:50:24

featureData(eset):
An object of class 'AnnotatedDataFrame'
  featureNames: 1007_s_at 1053_at ... AFFX-HUMISGF3A/M97935_MB_at
    (42447 total)
  varLabels: probeset gene EntrezGene.ID best_probe
  varMetadata: labelDescription

}}
\details{
\preformatted{
assayData: 42447 features, 58 samples
Platform type:
Overall survival time-to-event summary (in years):
Call: survfit(formula = Surv(time, cens) ~ -1)

      n  events  median 0.95LCL 0.95UCL
  58.00   36.00    4.19    2.70    6.17

---------------------------
Available sample meta-data:
---------------------------

alt_sample_name:
 OV_FFPE_1 OV_FFPE_10 OV_FFPE_11 OV_FFPE_12 OV_FFPE_13 OV_FFPE_14 OV_FFPE_15
         1          1          1          1          1          1          1
OV_FFPE_16 OV_FFPE_17 OV_FFPE_18 OV_FFPE_19  OV_FFPE_2 OV_FFPE_20 OV_FFPE_21
         1          1          1          1          1          1          1
OV_FFPE_22 OV_FFPE_23 OV_FFPE_24 OV_FFPE_25 OV_FFPE_26 OV_FFPE_27 OV_FFPE_28
         1          1          1          1          1          1          1
OV_FFPE_29  OV_FFPE_3 OV_FFPE_30 OV_FFPE_31 OV_FFPE_32 OV_FFPE_33 OV_FFPE_34
         1          1          1          1          1          1          1
OV_FFPE_35 OV_FFPE_36 OV_FFPE_37 OV_FFPE_38 OV_FFPE_39  OV_FFPE_4 OV_FFPE_40
         1          1          1          1          1          1          1
OV_FFPE_41 OV_FFPE_42 OV_FFPE_43 OV_FFPE_44 OV_FFPE_45 OV_FFPE_46 OV_FFPE_47
         1          1          1          1          1          1          1
OV_FFPE_48 OV_FFPE_49  OV_FFPE_5 OV_FFPE_50 OV_FFPE_51 OV_FFPE_52 OV_FFPE_53
         1          1          1          1          1          1          1
OV_FFPE_54 OV_FFPE_55 OV_FFPE_56 OV_FFPE_57 OV_FFPE_58  OV_FFPE_6  OV_FFPE_7
         1          1          1          1          1          1          1
 OV_FFPE_8  OV_FFPE_9
         1          1

sample_type:
tumor
   58

histological_type:
       clearcell             endo         mucinous            other
               5                1                1                1
             ser undifferentiated             NA's
              47                1                2

summarygrade:
high  low NA's
  33   21    4

summarystage:
late
  58

tumorstage:
 3  4
53  5

substage:
 a  b  c
 9 11 38

grade:
   1    2    3 NA's
   2   19   33    4

age_at_initial_pathologic_diagnosis:
   Min. 1st Qu.  Median    Mean 3rd Qu.    Max.
  38.00   53.50   62.00   62.57   72.00   85.00

pltx:
 y
58

tax:
 n  y
 4 54

neo:
 n
58

days_to_tumor_recurrence:
   Min. 1st Qu.  Median    Mean 3rd Qu.    Max.
   12.0   255.2   386.0   742.1   768.2  4208.0

recurrence_status:
norecurrence   recurrence         NA's
           6           48            4

days_to_death:
   Min. 1st Qu.  Median    Mean 3rd Qu.    Max.
   49.0   585.2  1010.0  1375.0  2131.0  4208.0

vital_status:
deceased   living
      36       22

debulking:
   optimal suboptimal       NA's
        26         30          2

batch:
2009-10-07 2009-10-08 2009-10-09 2009-10-20
        28         18          8          4

uncurated_author_metadata:
            title: OV_FFPE_10///geo_accession: GSM746870///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 76///characteristics_ch1.2: dob: 1921-11-18///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Clear///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1998-11-01///characteristics_ch1.9: surgdate: 1998-11-01///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PR (partial response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1998-12-01///characteristics_ch1.15: date.last.follow.up: 1998-12-20///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 30///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 49///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F021.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746870/GSM746870.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: OV_FFPE_11///geo_accession: GSM746871///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 75///characteristics_ch1.2: dob: 1918-12-09///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1995-03-07///characteristics_ch1.9: surgdate: 1995-03-07///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1996-04-11///characteristics_ch1.15: date.last.follow.up: 1996-06-19///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 401///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 470///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F022.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746871/GSM746871.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
    title: OV_FFPE_12///geo_accession: GSM746872///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 78///characteristics_ch1.2: dob: 1925-03-13///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1996-11-12///characteristics_ch1.9: surgdate: 1996-11-12///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PR (partial response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1998-04-01///characteristics_ch1.15: date.last.follow.up: 2004-11-13///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 505///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 2923///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F025.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746872/GSM746872.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
    title: OV_FFPE_13///geo_accession: GSM746873///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 58///characteristics_ch1.2: dob: 1938-05-02///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1997-02-05///characteristics_ch1.9: surgdate: 1997-02-05///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PR (partial response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1998-07-01///characteristics_ch1.15: date.last.follow.up: 2002-07-22///characteristics_ch1.16: st.categ: 2///characteristics_ch1.17: pfi days: 511///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 1993///characteristics_ch1.20: censoring(dead=1,alive=0): 0///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F027.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746873/GSM746873.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
   title: OV_FFPE_14///geo_accession: GSM746874///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 50///characteristics_ch1.2: dob: 1953-04-09///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Clear///characteristics_ch1.5: grade: Unk///characteristics_ch1.6: Stage: IIIB///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 2002-06-06///characteristics_ch1.9: surgdate: 2002-06-06///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 2003-10-13///characteristics_ch1.15: date.last.follow.up: 2005-10-24///characteristics_ch1.16: st.categ: 2///characteristics_ch1.17: pfi days: 494///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 1236///characteristics_ch1.20: censoring(dead=1,alive=0): 0///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F028.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746874/GSM746874.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                          title: OV_FFPE_15///geo_accession: GSM746875///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 61///characteristics_ch1.2: dob: 1941-12-01///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 2002-04-23///characteristics_ch1.9: surgdate: 2002-04-23///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PR (partial response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.last.follow.up: 2002-11-04///characteristics_ch1.15: st.categ: 2///characteristics_ch1.16: pfi days: 195///characteristics_ch1.17: relapse(1=yes, 0=no): UNKnown///characteristics_ch1.18: overall survival days: 195///characteristics_ch1.19: censoring(dead=1,alive=0): 0///characteristics_ch1.20: ///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F030.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746875/GSM746875.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
      title: OV_FFPE_16///geo_accession: GSM746876///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 53///characteristics_ch1.2: dob: 1943-07-22///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Mod///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1997-01-01///characteristics_ch1.9: surgdate: 1997-01-01///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PR (partial response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1997-02-01///characteristics_ch1.15: date.last.follow.up: 2000-04-27///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 31///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 1212///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F032.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746876/GSM746876.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
       title: OV_FFPE_17///geo_accession: GSM746877///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 73///characteristics_ch1.2: dob: 1923-05-23///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Mod///characteristics_ch1.6: Stage: IVA///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1996-07-30///characteristics_ch1.9: surgdate: 1996-07-30///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PR (partial response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1997-04-01///characteristics_ch1.15: date.last.follow.up: 1997-03-29///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 245///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 242///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F033.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746877/GSM746877.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                          title: OV_FFPE_18///geo_accession: GSM746878///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 85///characteristics_ch1.2: dob: 1910-04-01///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1996-01-04///characteristics_ch1.9: surgdate: 1996-01-04///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: unknown///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.last.follow.up: 2002-01-07///characteristics_ch1.15: st.categ: 6///characteristics_ch1.16: pfi days: 2195///characteristics_ch1.17: relapse(1=yes, 0=no): UNKnown///characteristics_ch1.18: overall survival days: 2195///characteristics_ch1.19: censoring(dead=1,alive=0): 1///characteristics_ch1.20: ///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F034.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746878/GSM746878.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                                           title: OV_FFPE_19///geo_accession: GSM746879///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 68///characteristics_ch1.2: dob: 1930-02-21///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Mod///characteristics_ch1.6: Stage: IIIA///characteristics_ch1.7: datedx: 1998-06-18///characteristics_ch1.8: surgdate: 1998-06-18///characteristics_ch1.9: optimal: Optimal///characteristics_ch1.10: chemtype: Adjuvant///characteristics_ch1.11: chemoresponse: CR (completely response)///characteristics_ch1.12: chemo agent: Cisplatin/Taxol///characteristics_ch1.13: date.last.follow.up: 2004-09-16///characteristics_ch1.14: st.categ: 1///characteristics_ch1.15: pfi days: 2282///characteristics_ch1.16: relapse(1=yes, 0=no): 0///characteristics_ch1.17: overall survival days: 2282///characteristics_ch1.18: censoring(dead=1,alive=0): 0///characteristics_ch1.19: ///characteristics_ch1.20: ///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F036.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746879/GSM746879.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
       title: OV_FFPE_1///geo_accession: GSM746861///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 68///characteristics_ch1.2: dob: 1930-03-16///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IVA///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1998-05-12///characteristics_ch1.9: surgdate: 1998-05-12///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PR (partial response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1999-06-01///characteristics_ch1.15: date.last.follow.up: 2000-03-28///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 385///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 686///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F001.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746861/GSM746861.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: OV_FFPE_20///geo_accession: GSM746880///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 56///characteristics_ch1.2: dob: 1938-10-21///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1995-10-04///characteristics_ch1.9: surgdate: 1995-10-12///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1996-08-08///characteristics_ch1.15: date.last.follow.up: 1997-12-30///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 309///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 818///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F037.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746880/GSM746880.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                      title: OV_FFPE_21///geo_accession: GSM746881///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 66///characteristics_ch1.2: dob: 1930-07-05///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Transitional///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IVA///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1996-09-24///characteristics_ch1.9: surgdate: 1996-09-24///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.last.follow.up: 2005-10-22///characteristics_ch1.15: st.categ: 1///characteristics_ch1.16: pfi days: 3315///characteristics_ch1.17: relapse(1=yes, 0=no): 0///characteristics_ch1.18: overall survival days: 3315///characteristics_ch1.19: censoring(dead=1,alive=0): 0///characteristics_ch1.20: ///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F039.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746881/GSM746881.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                            title: OV_FFPE_22///geo_accession: GSM746882///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 71///characteristics_ch1.2: dob: 1926-11-13///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIB///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1997-09-09///characteristics_ch1.9: surgdate: 1997-09-09///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: unknown///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.last.follow.up: 1998-10-01///characteristics_ch1.15: st.categ: 4///characteristics_ch1.16: pfi days: 387///characteristics_ch1.17: relapse(1=yes, 0=no): UNKnown///characteristics_ch1.18: overall survival days: 387///characteristics_ch1.19: censoring(dead=1,alive=0): 1///characteristics_ch1.20: ///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F044.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746882/GSM746882.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
          title: OV_FFPE_23///geo_accession: GSM746883///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 57///characteristics_ch1.2: dob: 1946-10-13///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Clear///characteristics_ch1.5: grade: Unk///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 2002-07-18///characteristics_ch1.9: surgdate: 2002-07-18///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PR (partial response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 2003-05-01///characteristics_ch1.15: date.last.follow.up: 2004-05-07///characteristics_ch1.16: st.categ: 2///characteristics_ch1.17: pfi days: 287///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 659///characteristics_ch1.20: censoring(dead=1,alive=0): 0///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F045a.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746883/GSM746883.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
        title: OV_FFPE_24///geo_accession: GSM746884///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 55///characteristics_ch1.2: dob: 1948-10-12///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Well///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 2002-04-29///characteristics_ch1.9: surgdate: 2002-04-29///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PR (partial response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 2003-05-01///characteristics_ch1.15: date.last.follow.up: 2006-08-25///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 367///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 1579///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F047.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746884/GSM746884.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
       title: OV_FFPE_25///geo_accession: GSM746885///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 74///characteristics_ch1.2: dob: 1922-02-09///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Mod///characteristics_ch1.6: Stage: IIIB///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1997-02-04///characteristics_ch1.9: surgdate: 1997-02-04///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Cisplatin/Cytoxan///characteristics_ch1.14: date.of.relapse: 1998-07-31///characteristics_ch1.15: date.last.follow.up: 1999-10-17///characteristics_ch1.16: st.categ: 6///characteristics_ch1.17: pfi days: 542///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 985///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F048.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746885/GSM746885.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
     title: OV_FFPE_26///geo_accession: GSM746886///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 72///characteristics_ch1.2: dob: 1924-01-11///characteristics_ch1.3: race: Black///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1996-08-20///characteristics_ch1.9: surgdate: 1996-08-20///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PR (partial response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1997-02-01///characteristics_ch1.15: date.last.follow.up: 1997-04-14///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 165///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 237///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F049.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746886/GSM746886.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
   title: OV_FFPE_27///geo_accession: GSM746887///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 72///characteristics_ch1.2: dob: 1931-09-07///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 2002-08-01///characteristics_ch1.9: surgdate: 2002-08-27///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PD (progress of disease)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 2002-09-01///characteristics_ch1.15: date.last.follow.up: 2002-12-16///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 31///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 137///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F050.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746887/GSM746887.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                title: OV_FFPE_28///geo_accession: GSM746888///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 74///characteristics_ch1.2: dob: 1927-01-10///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Undiff///characteristics_ch1.5: grade: Mod///characteristics_ch1.6: Stage: IIIB///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 2001-07-17///characteristics_ch1.9: surgdate: 2001-07-17///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.last.follow.up: 2007-09-10///characteristics_ch1.15: st.categ: 1///characteristics_ch1.16: pfi days: 2246///characteristics_ch1.17: relapse(1=yes, 0=no): 0///characteristics_ch1.18: overall survival days: 2246///characteristics_ch1.19: censoring(dead=1,alive=0): 0///characteristics_ch1.20: ///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F051.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746888/GSM746888.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
      title: OV_FFPE_29///geo_accession: GSM746889///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 66///characteristics_ch1.2: dob: 1935-06-11///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 2001-10-08///characteristics_ch1.9: surgdate: 2001-10-08///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 2003-02-01///characteristics_ch1.15: date.last.follow.up: 2003-09-05///characteristics_ch1.16: st.categ: 2///characteristics_ch1.17: pfi days: 481///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 697///characteristics_ch1.20: censoring(dead=1,alive=0): 0///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F053.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746889/GSM746889.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
      title: OV_FFPE_2///geo_accession: GSM746862///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 75///characteristics_ch1.2: dob: 1921-11-24///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Mod///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1997-05-14///characteristics_ch1.9: surgdate: 1997-05-14///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 2004-06-08///characteristics_ch1.15: date.last.follow.up: 2004-06-08///characteristics_ch1.16: st.categ: 2///characteristics_ch1.17: pfi days: 2582///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 2582///characteristics_ch1.20: censoring(dead=1,alive=0): 0///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F005.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746862/GSM746862.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
           title: OV_FFPE_30///geo_accession: GSM746890///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 56///characteristics_ch1.2: dob: 1946-06-06///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Mod///characteristics_ch1.6: Stage: IIIA///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 2003-01-07///characteristics_ch1.9: surgdate: 2003-01-07///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin///characteristics_ch1.14: date.of.relapse: 2005-10-06///characteristics_ch1.15: date.last.follow.up: 2008-11-19///characteristics_ch1.16: st.categ: 2///characteristics_ch1.17: pfi days: 1003///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 2143///characteristics_ch1.20: censoring(dead=1,alive=0): 0///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F054.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746890/GSM746890.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
       title: OV_FFPE_31///geo_accession: GSM746891///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 64///characteristics_ch1.2: dob: 1931-07-12///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Mod///characteristics_ch1.6: Stage: IIIB///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1996-02-15///characteristics_ch1.9: surgdate: 1996-02-15///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1997-03-01///characteristics_ch1.15: date.last.follow.up: 1998-01-19///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 380///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 704///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F056.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746891/GSM746891.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
 title: OV_FFPE_32///geo_accession: GSM746892///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 53///characteristics_ch1.2: dob: 1945-06-08///characteristics_ch1.3: race: Black///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1998-06-02///characteristics_ch1.9: surgdate: 1998-06-02///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1999-06-04///characteristics_ch1.15: date.last.follow.up: 2002-09-10///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 367///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 1561///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F057.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746892/GSM746892.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: OV_FFPE_33///geo_accession: GSM746893///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 76///characteristics_ch1.2: dob: 1918-12-23///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1995-10-05///characteristics_ch1.9: surgdate: 1995-10-12///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1996-09-11///characteristics_ch1.15: date.last.follow.up: 1998-08-13///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 342///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 1043///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F058d.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746893/GSM746893.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
          title: OV_FFPE_34///geo_accession: GSM746894///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 84///characteristics_ch1.2: dob: 1918-11-04///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Clear///characteristics_ch1.5: grade: Unk///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 2002-02-19///characteristics_ch1.9: surgdate: 2002-02-19///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PR (partial response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 2002-11-11///characteristics_ch1.15: date.last.follow.up: 2006-10-23///characteristics_ch1.16: st.categ: 2///characteristics_ch1.17: pfi days: 265///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 1707///characteristics_ch1.20: censoring(dead=1,alive=0): 0///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F059.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746894/GSM746894.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: OV_FFPE_35///geo_accession: GSM746895///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 73///characteristics_ch1.2: dob: 1924-01-17///characteristics_ch1.3: race: Black///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IVA///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1998-01-06///characteristics_ch1.9: surgdate: 1998-01-06///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1999-05-01///characteristics_ch1.15: date.last.follow.up: 2001-03-03///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 480///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 1152///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F060.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746895/GSM746895.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
      title: OV_FFPE_36///geo_accession: GSM746896///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 62///characteristics_ch1.2: dob: 1935-02-10///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Unknown///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1997-04-08///characteristics_ch1.9: surgdate: 1997-04-08///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin///characteristics_ch1.14: date.of.relapse: 1999-02-01///characteristics_ch1.15: date.last.follow.up: 2001-06-15///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 664///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 1529///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F061.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746896/GSM746896.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                  title: OV_FFPE_37///geo_accession: GSM746897///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 51///characteristics_ch1.2: dob: 1945-01-31///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Mod///characteristics_ch1.6: Stage: IIIB///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1996-09-24///characteristics_ch1.9: surgdate: 1996-09-24///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Cisplatin/Taxol///characteristics_ch1.14: date.last.follow.up: 2008-04-02///characteristics_ch1.15: st.categ: 1///characteristics_ch1.16: pfi days: 4208///characteristics_ch1.17: relapse(1=yes, 0=no): 0///characteristics_ch1.18: overall survival days: 4208///characteristics_ch1.19: censoring(dead=1,alive=0): 0///characteristics_ch1.20: ///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F062.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746897/GSM746897.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
 title: OV_FFPE_38///geo_accession: GSM746898///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 38///characteristics_ch1.2: dob: 1958-02-02///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Mod///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1997-05-27///characteristics_ch1.9: surgdate: 1997-05-27///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Cytoxan///characteristics_ch1.14: date.of.relapse: 1998-04-13///characteristics_ch1.15: date.last.follow.up: 1998-08-04///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 321///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 434///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F063.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746898/GSM746898.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
     title: OV_FFPE_39///geo_accession: GSM746899///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 49///characteristics_ch1.2: dob: 1948-09-09///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1998-01-27///characteristics_ch1.9: surgdate: 1998-01-27///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1999-04-03///characteristics_ch1.15: date.last.follow.up: 2005-06-29///characteristics_ch1.16: st.categ: 2///characteristics_ch1.17: pfi days: 431///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 2710///characteristics_ch1.20: censoring(dead=1,alive=0): 0///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F064.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746899/GSM746899.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
      title: OV_FFPE_3///geo_accession: GSM746863///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 52///characteristics_ch1.2: dob: 1944-10-28///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1997-03-25///characteristics_ch1.9: surgdate: 1997-04-17///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PR (partial response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1997-09-16///characteristics_ch1.15: date.last.follow.up: 1998-11-10///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 175///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 595///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F008.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746863/GSM746863.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
     title: OV_FFPE_40///geo_accession: GSM746900///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 55///characteristics_ch1.2: dob: 1943-11-30///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1998-04-23///characteristics_ch1.9: surgdate: 1998-04-23///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 2000-11-07///characteristics_ch1.15: date.last.follow.up: 2004-01-17///characteristics_ch1.16: st.categ: 3///characteristics_ch1.17: pfi days: 929///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 2095///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F065.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746900/GSM746900.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                           title: OV_FFPE_41///geo_accession: GSM746901///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 74///characteristics_ch1.2: dob: 1929-07-21///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Endometrioid///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIB///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 2002-01-10///characteristics_ch1.9: surgdate: 2002-01-10///characteristics_ch1.10: chemtype: Adjuvant///characteristics_ch1.11: chemoresponse: CR (completely response)///characteristics_ch1.12: chemo agent: Carboplatin/Taxol///characteristics_ch1.13: date.last.follow.up: 2002-05-15///characteristics_ch1.14: st.categ: 1///characteristics_ch1.15: pfi days: 125///characteristics_ch1.16: relapse(1=yes, 0=no): 0///characteristics_ch1.17: overall survival days: 125///characteristics_ch1.18: censoring(dead=1,alive=0): 0///characteristics_ch1.19: ///characteristics_ch1.20: ///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F069.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746901/GSM746901.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: OV_FFPE_42///geo_accession: GSM746902///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 66///characteristics_ch1.2: dob: 1936-08-14///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 2001-09-07///characteristics_ch1.9: surgdate: 2001-09-18///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 2002-08-01///characteristics_ch1.15: date.last.follow.up: 2004-05-22///characteristics_ch1.16: st.categ: 2///characteristics_ch1.17: pfi days: 328///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 988///characteristics_ch1.20: censoring(dead=1,alive=0): 0///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F070.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746902/GSM746902.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                               title: OV_FFPE_43///geo_accession: GSM746903///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 53///characteristics_ch1.2: dob: 1943-05-10///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Well///characteristics_ch1.6: Stage: IIIA///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1997-04-17///characteristics_ch1.9: surgdate: 1997-04-17///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.last.follow.up: 2007-04-09///characteristics_ch1.15: st.categ: 1///characteristics_ch1.16: pfi days: 3644///characteristics_ch1.17: relapse(1=yes, 0=no): 0///characteristics_ch1.18: overall survival days: 3644///characteristics_ch1.19: censoring(dead=1,alive=0): 0///characteristics_ch1.20: ///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F072.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746903/GSM746903.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
 title: OV_FFPE_44///geo_accession: GSM746904///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 61///characteristics_ch1.2: dob: 1942-07-17///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 2002-02-22///characteristics_ch1.9: surgdate: 2002-02-22///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 2004-05-13///characteristics_ch1.15: date.last.follow.up: 2009-01-09///characteristics_ch1.16: st.categ: 2///characteristics_ch1.17: pfi days: 811///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 2513///characteristics_ch1.20: censoring(dead=1,alive=0): 0///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F074.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746904/GSM746904.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
 title: OV_FFPE_45///geo_accession: GSM746905///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 62///characteristics_ch1.2: dob: 1941-10-29///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1996-10-10///characteristics_ch1.9: surgdate: 1996-10-10///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1999-03-01///characteristics_ch1.15: date.last.follow.up: 2007-06-04///characteristics_ch1.16: st.categ: 2///characteristics_ch1.17: pfi days: 872///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 3889///characteristics_ch1.20: censoring(dead=1,alive=0): 0///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F076.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746905/GSM746905.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
     title: OV_FFPE_46///geo_accession: GSM746906///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 69///characteristics_ch1.2: dob: 1925-11-13///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Mod///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1995-09-19///characteristics_ch1.9: surgdate: 1995-09-26///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PR (partial response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1997-12-01///characteristics_ch1.15: date.last.follow.up: 2001-11-17///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 804///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 2251///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F081.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746906/GSM746906.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
     title: OV_FFPE_47///geo_accession: GSM746907///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 70///characteristics_ch1.2: dob: 1925-04-20///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Mod///characteristics_ch1.6: Stage: IIIB///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1995-08-08///characteristics_ch1.9: surgdate: 1995-08-08///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PR (partial response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1997-03-10///characteristics_ch1.15: date.last.follow.up: 2003-04-03///characteristics_ch1.16: st.categ: 6///characteristics_ch1.17: pfi days: 580///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 2795///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F082.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746907/GSM746907.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                          title: OV_FFPE_48///geo_accession: GSM746908///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 64///characteristics_ch1.2: dob: 1939-04-18///characteristics_ch1.3: race: Black///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IVA///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 2002-04-09///characteristics_ch1.9: surgdate: 2002-04-09///characteristics_ch1.10: chemtype: Adjuvant///characteristics_ch1.11: chemoresponse: PR (partial response)///characteristics_ch1.12: chemo agent: Carboplatin/Taxol///characteristics_ch1.13: date.of.relapse: 2003-02-01///characteristics_ch1.14: date.last.follow.up: 2004-04-20///characteristics_ch1.15: st.categ: 4///characteristics_ch1.16: pfi days: 298///characteristics_ch1.17: relapse(1=yes, 0=no): 1///characteristics_ch1.18: overall survival days: 742///characteristics_ch1.19: censoring(dead=1,alive=0): 1///characteristics_ch1.20: ///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F083.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746908/GSM746908.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
      title: OV_FFPE_49///geo_accession: GSM746909///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 66///characteristics_ch1.2: dob: 1932-01-12///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Mucinous///characteristics_ch1.5: grade: Mod///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1998-01-20///characteristics_ch1.9: surgdate: 1998-01-20///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PR (partial response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1998-02-01///characteristics_ch1.15: date.last.follow.up: 1998-04-24///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 12///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 94///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F087.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746909/GSM746909.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
           title: OV_FFPE_4///geo_accession: GSM746864///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 47///characteristics_ch1.2: dob: 1950-05-11///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Mod///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1997-10-21///characteristics_ch1.9: surgdate: 1997-10-21///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PR (partial response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1998-04-01///characteristics_ch1.15: date.last.follow.up: 1998-11-02///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 162///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 377///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F009.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746864/GSM746864.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
      title: OV_FFPE_50///geo_accession: GSM746910///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 60///characteristics_ch1.2: dob: 1938-05-27///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Unk///characteristics_ch1.6: Stage: IIIB///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1998-11-18///characteristics_ch1.9: surgdate: 1998-11-18///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PR (partial response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1999-08-27///characteristics_ch1.15: date.last.follow.up: 2000-08-06///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 282///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 627///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F088.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746910/GSM746910.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
        title: OV_FFPE_51///geo_accession: GSM746911///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 59///characteristics_ch1.2: dob: 1936-04-23///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Mod///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1996-01-25///characteristics_ch1.9: surgdate: 1996-01-30///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PR (partial response)///characteristics_ch1.13: chemo agent: Cisplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1996-08-30///characteristics_ch1.15: date.last.follow.up: 1996-12-08///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 218///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 318///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F090.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746911/GSM746911.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
        title: OV_FFPE_52///geo_accession: GSM746912///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 72///characteristics_ch1.2: dob: 1925-12-29///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Mod///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1998-10-21///characteristics_ch1.9: surgdate: 1998-10-21///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PR (partial response)///characteristics_ch1.13: chemo agent: Cisplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1999-02-12///characteristics_ch1.15: date.last.follow.up: 2001-06-20///characteristics_ch1.16: st.categ: 2///characteristics_ch1.17: pfi days: 114///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 973///characteristics_ch1.20: censoring(dead=1,alive=0): 0///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F092.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746912/GSM746912.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
     title: OV_FFPE_53///geo_accession: GSM746913///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 52///characteristics_ch1.2: dob: 1943-08-27///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIB///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1996-03-12///characteristics_ch1.9: surgdate: 1996-03-12///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1997-09-29///characteristics_ch1.15: date.last.follow.up: 1999-01-07///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 566///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 1031///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F093.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746913/GSM746913.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
     title: OV_FFPE_54///geo_accession: GSM746914///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 51///characteristics_ch1.2: dob: 1952-06-04///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 2002-07-05///characteristics_ch1.9: surgdate: 2002-07-05///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 2004-09-15///characteristics_ch1.15: date.last.follow.up: 2006-08-14///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 803///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 1501///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F095.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746914/GSM746914.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
      title: OV_FFPE_55///geo_accession: GSM746915///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 56///characteristics_ch1.2: dob: 1947-02-10///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Mod///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 2002-07-10///characteristics_ch1.9: surgdate: 2002-07-10///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 2003-04-01///characteristics_ch1.15: date.last.follow.up: 2007-07-30///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 265///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 1846///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F096.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746915/GSM746915.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: OV_FFPE_56///geo_accession: GSM746916///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 44///characteristics_ch1.2: dob: 1952-02-16///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1997-02-11///characteristics_ch1.9: surgdate: 1997-02-11///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1998-03-25///characteristics_ch1.15: date.last.follow.up: 1998-09-16///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 407///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 582///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F098.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746916/GSM746916.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                           title: OV_FFPE_57///geo_accession: GSM746917///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 61///characteristics_ch1.2: dob: 1941-12-14///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Unknown///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 2002-01-31///characteristics_ch1.9: surgdate: 2002-01-31///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: Unknown///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.last.follow.up: 2002-08-27///characteristics_ch1.15: st.categ: 1///characteristics_ch1.16: pfi days: 208///characteristics_ch1.17: relapse(1=yes, 0=no): UNKnown///characteristics_ch1.18: overall survival days: 208///characteristics_ch1.19: censoring(dead=1,alive=0): 0///characteristics_ch1.20: ///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F099.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746917/GSM746917.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
     title: OV_FFPE_58///geo_accession: GSM746918///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 74///characteristics_ch1.2: dob: 1920-09-07///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Mod///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1995-08-08///characteristics_ch1.9: surgdate: 1995-08-08///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PR (partial response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1996-06-12///characteristics_ch1.15: date.last.follow.up: 2000-02-25///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 309///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 1662///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F100.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746918/GSM746918.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
        title: OV_FFPE_5///geo_accession: GSM746865///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 69///characteristics_ch1.2: dob: 1934-08-29///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Clear///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIB///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 2001-12-06///characteristics_ch1.9: surgdate: 2001-12-06///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 2004-04-14///characteristics_ch1.15: date.last.follow.up: 2004-05-21///characteristics_ch1.16: st.categ: 2///characteristics_ch1.17: pfi days: 860///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 897///characteristics_ch1.20: censoring(dead=1,alive=0): 0///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F010.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746865/GSM746865.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
        title: OV_FFPE_6///geo_accession: GSM746866///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 48///characteristics_ch1.2: dob: 1950-08-03///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Mod///characteristics_ch1.6: Stage: IIIA///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1999-04-01///characteristics_ch1.9: surgdate: 1999-04-01///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Cisplatin/Taxol///characteristics_ch1.14: date.of.relapse: 2007-07-13///characteristics_ch1.15: date.last.follow.up: 2008-11-10///characteristics_ch1.16: st.categ: 2///characteristics_ch1.17: pfi days: 3025///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 3511///characteristics_ch1.20: censoring(dead=1,alive=0): 0///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F014.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746866/GSM746866.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
       title: OV_FFPE_7///geo_accession: GSM746867///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 52///characteristics_ch1.2: dob: 1945-11-16///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1998-07-28///characteristics_ch1.9: surgdate: 1998-07-28///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1999-10-25///characteristics_ch1.15: date.last.follow.up: 2001-03-19///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 454///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 965///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F017.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746867/GSM746867.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
        title: OV_FFPE_8///geo_accession: GSM746868///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 55///characteristics_ch1.2: dob: 1942-12-07///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1998-04-23///characteristics_ch1.9: surgdate: 1998-04-23///characteristics_ch1.10: optimal: Optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: CR (completely response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1998-07-21///characteristics_ch1.15: date.last.follow.up: 2000-05-11///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 89///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 749///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F018.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746868/GSM746868.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
      title: OV_FFPE_9///geo_accession: GSM746869///status: Public on Aug 21 2012///submission_date: Jun 22 2011///last_update_date: Aug 21 2012///type: RNA///channel_count: 1///source_name_ch1: formalin-fixed paraffin embedded (FFPE) tissue, ovarian cancer cells///organism_ch1: Homo sapiens///characteristics_ch1: cell type: ovarian cancer cell///characteristics_ch1.1: age: 48///characteristics_ch1.2: dob: 1950-02-15///characteristics_ch1.3: race: White///characteristics_ch1.4: histo: Serous///characteristics_ch1.5: grade: Poor///characteristics_ch1.6: Stage: IIIC///characteristics_ch1.7: surgtype: Primary Surgery///characteristics_ch1.8: datedx: 1998-10-20///characteristics_ch1.9: surgdate: 1998-10-29///characteristics_ch1.10: optimal: Sub-optimal///characteristics_ch1.11: chemtype: Adjuvant///characteristics_ch1.12: chemoresponse: PR (partial response)///characteristics_ch1.13: chemo agent: Carboplatin/Taxol///characteristics_ch1.14: date.of.relapse: 1999-06-29///characteristics_ch1.15: date.last.follow.up: 2000-02-08///characteristics_ch1.16: st.categ: 4///characteristics_ch1.17: pfi days: 252///characteristics_ch1.18: relapse(1=yes, 0=no): 1///characteristics_ch1.19: overall survival days: 476///characteristics_ch1.20: censoring(dead=1,alive=0): 1///molecule_ch1: total RNA///extract_protocol_ch1: RNA extraction and amplification was performed with the NuGen WT-Ovation FFPE RNA Amplification kit.///label_ch1: biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 6 ug total RNA (Expression Analysis Technical Manual, 2001, Affymetrix).///taxid_ch1: 9606///hyb_protocol: Punches of FFPE tumor tissue blocks and gene expression profiling were performed in a standard procedure by Almac Dignostics, Inc. (Durham, NC).///scan_protocol: GeneChips were scanned using the Hewlett-Packard GeneArray Scanner G2500A.///description: S0456F019.CEL///description.1: Gene expression data from stage III-IV ovarian cancer patients///data_processing: Data normalization and quality control assessment of the hybridization results were performed with the RMA Bioconductor package (http://www.bioconductor.org)///platform_id: GPL570///contact_name: Youngchul,,Kim///contact_department: Public Health Sciences///contact_institute: University of Virginia///contact_address: University street///contact_city: Charlottesville///contact_state: VA///contact_zip.postal_code: 22903///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nlm.nih.gov/pub/geo/DATA/supplementary/samples/GSM746nnn/GSM746869/GSM746869.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1

}}
\keyword{datasets}
